<?php
/*
@package kryex Nx theme

============================================
  Nx THEME SUPPORT
============================================
*/

add_filter( 'wp_lazy_loading_enabled', 'wp_lazyload_disable', 10, 3 );
function wp_lazyload_disable( $default, $tag_name, $context ) {
    if ( 'img' === $tag_name && 'wp_get_attachment_image' === $context ) {
        return false;
    }
    return $default;
}

/* disable lazyload end ================================================== */

if ( ! function_exists( 'kryex_theme_support' ) ) {
  function kryex_theme_support() {
    // Let WordPress manage the document title (no hard-coded <title> tag in the document head)
    add_theme_support( 'title-tag' );
    // Enables post and comment RSS feed links to head
    add_theme_support( 'automatic-feed-links' );
    // Add thumbnail theme support
    add_theme_support( 'post-thumbnails' );
    // post format
    add_theme_support( 'post-formats', array( 'gallery', 'video' ) );
    //Remove widgets block editor
    remove_theme_support('widgets-block-editor');
    
  }
}
add_action( 'after_setup_theme', 'kryex_theme_support' );


/* Remove anything that looks like an archive title prefix ("Archive:", "Foo:", "Bar:") ======= */
add_filter( 'get_the_archive_title', function ( $title ) {
    if( is_category() ) {
        $title = sprintf( __( '%s' ), single_term_title( '', false ) );
    }
    return $title;

});


/* Modify the menu classes ==================================================== */
add_filter( 'nav_menu_css_class', 'special_current_nav_class', 10, 4 );
function special_current_nav_class( $classes, $item, $args, $depth = 0 ) {

  $current_classes = array(
    'current-menu-item',
    'current-menu-parent',
    'current-menu-ancestor',
    'current_page_parent',
    'current-page-ancestor',
    'current-post-ancestor',
    'current-post-parent',
    'current-category-ancestor',
  );

  $current_classes = apply_filters( 'Nx/current_classes', $current_classes, $classes, $item, $args, $depth );

  foreach ( $classes as $class ){
    if( in_array( $class, $current_classes )){

      $classes[] = 'nx_Current';
      break;
    }
  }

  return $classes;
}

/* Navigation filter
==================================================
*/

add_filter( 'navigation_markup_template', 'nx_navigation_template' );
function nx_navigation_template( $template ) {
    $template = '
    <nav class="navigation %1$s">
        <div class="nav-links">%3$s</div>
    </nav>';

    return $template;

}

/* time format
==================================================
*/

function meks_time_ago() {
  return human_time_diff( get_the_time( 'U' ), current_time( 'timestamp' ) ).' '.__( 'önce' );
}

/* Halt the main query in the case of an empty search
==================================================
*/

add_filter( 'posts_search', function( $search, \WP_Query $q ) {
    if( ! is_admin() && empty( $search ) && $q->is_search() && $q->is_main_query() )
        $search .=" AND 0=1 ";
    return $search;
}, 10, 2 );

/* ONE CLİCK DEMO FUNCTİON
==================================================
*/

add_filter( 'pt-ocdi/import_files', 'kryex_import_files' );
function kryex_import_files() {
    return array(
        array(
            'import_file_name'           => esc_html__( 'Kryex Nano', KRYEX_TEXT ),
            'import_file_url'            => KRYEX_THEME_URI . '/demo/kryexnano.xml',
            'import_widget_file_url'     => KRYEX_THEME_URI . '/demo/kryexnano.wie',
            'import_preview_image_url'   => KRYEX_THEME_URI . '/demo/nano-demo.jpg',
            'import_notice'              => esc_html__( 'Kryex Nano Temasının demosunu içe aktarın.', KRYEX_TEXT ),
        ),
        array(
            'import_file_name'           => ' ',
            'import_preview_image_url'   => KRYEX_THEME_URI . '/demo/placeholder.png',
        ),
    );
}

add_action( 'pt-ocdi/after_import', 'kryex_after_import_setup' );
function kryex_after_import_setup() {
    // Assign menus to their locations.
    $main_menu = get_term_by( 'name', 'Main menu', 'main-menu' );
    $top_menu = get_term_by( 'name', 'Mobil menü', 'mobile-menu' );

    set_theme_mod( 'nav_menu_locations', array(
        'primary-menu' => $main_menu->term_id,
        'top-menu' => $top_menu->term_id,
      )
    );

}

/* Video embeds: Wrap video element in "div" container (to make them responsive)
==================================================
*/

add_filter( 'embed_oembed_html', 'qpin_wrap_oembed', 10, 3 );
function qpin_wrap_oembed( $html, $url, $attr ) {
    if ( false !== strpos( $url, 'vimeo.com' ) ) {
        return '<div class="embed-responsive embed-responsive-16by9">' . $html . '</div>';
    }
    if ( false !== strpos( $url, 'youtube.com' ) ) {
        return '<div class="embed-responsive embed-responsive-16by9">' . $html . '</div>';
    }
    if ( false !== strpos( $url, 'dailymotion.com' ) ) {
        return '<div class="embed-responsive embed-responsive-16by9">' . $html . '</div>';
    }
    if ( false !== strpos( $url, 'soundcloud.com' ) ) {
        return '<div class="embed-responsive embed-responsive-16by9">' . $html . '</div>';
    }
    
    return $html;
}

/* COMMENTS FUNCTİON
==================================================
*/

function kryex_posted_comments(){

  global $kryex;
  
  $tityorumlar = $kryex['tit_yorumlar'];
  $tityorumlar_kapali = $kryex['tit_yorumlar_kapali'];

  $num_comments = get_comments_number();

  if ( comments_open() ) {
    if ( $num_comments == 0 ) {
      $comments = __('0');
    } elseif ( $num_comments > 1 ) {
      $comments = $num_comments . __(' ');
    } else {
      $comments = __('1');
    }
    $write_comments = '<a title="'.$tityorumlar.'" href="' . get_comments_link() . '" class="kryex-comments"><i class="icofont-comment"></i> '. $comments .' </a>';
  } else {
    $write_comments = '<span class="kryex-comments closed">'. $tityorumlar_kapali .'</span>';
  }
  
  return ''. $write_comments .'';
}

/* VİEWS FUNCTİON
==================================================
*/

function getPostViews($postID){
    $count_key = 'post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
        return "0 ";
    }
    if ($count > 10000) {
        return round ( $count / 10000, 1 ).'K ';
    } else {
        return $count.' ';
    }
}

// function to count views.
function setPostViews($postID) {
    $count_key = 'post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        $count = 0;
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
    }else{
        $count++;
        update_post_meta($postID, $count_key, $count);
    }
}

/* POST NAVİGATİONS FUNCTİON
==================================================
*/

function kryex_post_navigation(){

  global $kryex;

  $prevPost = get_previous_post();
  if (!empty( $prevPost )) :
      $prevthumbnail = get_the_post_thumbnail_url($prevPost->ID, 'grid-thumb' );
  else :
      $prevthumbnail = '';
  endif;

  $nextPost = get_next_post();
  if (!empty( $nextPost )) :
      $nextthumbnail = get_the_post_thumbnail_url($nextPost->ID, 'grid-thumb' );
  else :
      $nextthumbnail = '';
  endif;

  $sonraki = $kryex['next_post'];
  $onceki  = $kryex['prev_post'];

  the_post_navigation( array(
    'prev_text' => '<div class="image lazyload" data-bgset="'.$prevthumbnail.'"><div class="post-link-nav"><span class="screen-text"><i class="icofont-long-arrow-left"></i> ' . $onceki. '</span>%title</div></div>',
    'next_text' => '<div class="image lazyload" data-bgset="'.$nextthumbnail.'"><div class="post-link-nav"><span class="screen-text">' .$sonraki. ' <i class="icofont-long-arrow-right"></i></span>%title</div></div>',
    'screen_reader_text' => ' ',
  ) );

}


/* Activate Nav Menu Option
==================================================
*/

if ( ! function_exists( 'nx_register_menus' ) ) {
  function nx_register_menus() {
    register_nav_menus( array(
      'main-menu'     => esc_html__( 'Main menu', KRYEX_TEXT ),
      'mobile-menu'   => esc_html__( 'Mobil menü', KRYEX_TEXT ),
    ) );
  }
}
add_action( 'init', 'nx_register_menus' );

/* SIDEBAR FUNCTION
==================================================
*/

add_action('widgets_init', 'nx_sidebar_init');
function nx_sidebar_init(){

  register_sidebar(
    array(
    'id'            => 'home-sidebar-top',
    'name'          => __( 'Anasayfa Üst Kısım', KRYEX_TEXT ),
    'description'   => __( 'Anasayfa bileşen alanı', KRYEX_TEXT ),
    'before_title'  => '<h3 class="widgettitle">',
    'after_title'   => '</h3>',
    'before_widget' => '<div id="%1$s" class="home-sidebar %2$s">',
    'after_widget'  => '</div>'
    )
  );

  register_sidebars(
    3, array(
    'name'          => esc_html__('Anasayfa %d', KRYEX_TEXT ),
    'id'            => 'home-sidebar',
    'description'   => 'Anasayfa bileşen alanları',
    'before_title'  => '<div class="section_title"><h3 class="widgettitle">',
    'after_title'   => '</h3></div>',
    'before_widget' => '<div id="%1$s" class="home-sidebar %2$s">',
    'after_widget'  => '</div>'
    )
  );

  register_sidebar(
    array(
    'id'            => 'archive_sidebar',
    'name'          => __( 'Arşiv & Single', KRYEX_TEXT ),
    'description'   => __( 'Arşiv ve İçerik sayfası bileşen alanı', KRYEX_TEXT ),
    'before_title'  => '<div class="section_title"><h3 class="widgettitle">',
    'after_title'   => '</h3></div>',
    'before_widget' => '<div id="%1$s" class="home-sidebar %2$s">',
    'after_widget'  => '</div>'
    )
  );

  register_sidebar(
    array(
    'id'            => 'copyright-sidebar',
    'name'          => __( 'Copyright', KRYEX_TEXT ),
    'description'   => __( 'Copright kısmına, oluşturduğunuz bir menüyü eklemek için bileşen alanı.', KRYEX_TEXT ),
    'before_widget' => '<div id="%1$s" class="%2$s">',
    'after_widget'  => '</div>'
    )
  );

}

/* Defer parsing of JavaScript
==================================================
*/

if (!(is_admin() )) {
  function defer_parsing_of_js ( $url ) {
    if ( FALSE === strpos( $url, '.js' ) ) return $url;
    return "$url' defer='defer";
  }
  add_filter( 'clean_url', 'defer_parsing_of_js', 11, 1 );
}

/* JS TYPE ATTRİBUTE JS DELETE
==================================================
*/

add_action('wp_loaded', 'output_buffer_start');
function output_buffer_start() { 
    ob_start("output_callback"); 
}
function output_callback($buffer) {
    return preg_replace( "%[ ]type=[\'\"]text\/(javascript|css)[\'\"]%", '', $buffer );
}

/* GRAVATAR DİSABLE END DEFAULT İMG
==================================================
*/

define('DEFAULT_AVATAR_URL', KRYEX_THEME_URI . '/img/default_avatar.jpg');
function no_gravatars( $avatar ) {
    return preg_replace( "/http.*?gravatar\.com[^\']*/", DEFAULT_AVATAR_URL, $avatar );
}
add_filter( 'get_avatar', 'no_gravatars' );

/* ADD İMAGE SİZE AND LAZYLOAD
==================================================
*/

function nx_setup_image_sizes() {
  add_image_size( 'thumb_small', 150, 100, true );
  add_image_size( 'thumb_medium', 380, 360, true );
  add_image_size( 'thumb_post', 500, 340, true );
  add_image_size( 'thumb_max', 570, 500, true );

}
add_action('after_setup_theme', 'nx_setup_image_sizes');

// Change src and srcset to data-src and data-srcset, and add class 'lazyload'
if ( !is_admin() ) {
  add_filter( 'wp_get_attachment_image_attributes', 'change_image_markup' );
  function change_image_markup($attributes){

    if ( has_post_format('gallery') and is_single() ) {
      return $attributes;
    }

    if (isset($attributes['src'])) {
      $attributes['data-src'] = $attributes['src'];
      $attributes['src'] = "data:image/svg+xml,%3Csvg%20xmlns%3D'http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg'%20width='400'%20height='272'%20viewBox%3D'0%200%20360%20320'%2F%3E";
    }
    if (isset($attributes['srcset'])) {
       $attributes['data-srcset'] = $attributes['srcset'];
       $attributes['srcset'] = '';
    }
    $attributes['class'] .= ' lazyload';
  
    return $attributes;

  }

}

// not cropped gif image
function gif_image( $image, $attachment_id, $size, $icon ){
  $file_type = wp_check_filetype( $image[0] );
  if( ! empty( $file_type ) && $file_type['ext'] == 'gif' && $size != 'full' ){
    $full_image = wp_get_attachment_image_src( $attachment_id, $size = 'full', $icon );
    return $full_image;
  }
  return $image;
}
add_filter( 'wp_get_attachment_image_src', 'gif_image', 10, 4 );


/* REMOVE WP EMOJİ
==================================================
*/

remove_action('wp_head', 'print_emoji_detection_script', 7);
remove_action('wp_print_styles', 'print_emoji_styles');

/* REMOVE LOGİN SHAKE
==================================================
*/

add_action('login_head', 'my_login_head');
function my_login_head() {
  remove_action('login_head', 'wp_shake_js', 12);
}

/* LOGIN CUSTOMIZER
================================================
*/

function kryex_custom_login() {
  echo '<link rel="stylesheet" type="text/css" href="' . get_bloginfo('stylesheet_directory') . '/inc/login/custom-login-styles.css" />';
}
add_action('login_head', 'kryex_custom_login');

function kryex_login_logo_url() {
  return get_bloginfo( 'url' );
}
add_filter( 'login_headerurl', 'kryex_login_logo_url' );

function kryex_login_logo_url_title() {
  return 'Anasayfa';
}
add_filter( 'login_headertext', 'kryex_login_logo_url_title' );

/* WP LOGİN LOGO
================================================
*/

function kryex_login_logo_one() {
  global $kryex; ?>
  <style type="text/css">
    body.login {background-image: url(<?php echo $kryex['logo_bg']['url']; ?>);}
    body.login h1 a {background-image: url(<?php echo $kryex['logo_upload']['url']; ?>);}
  </style><?php
} 
add_action( 'login_enqueue_scripts', 'kryex_login_logo_one' );


/* Custom comments markup
==================================================
*/

add_filter('get_comment_author_link', 'se_link_comment_to_archives');
function se_link_comment_to_archives( $link ) {
    global $comment;
    if ( !empty( $comment->user_id ) && !empty( get_userdata( $comment->user_id )->ID ) ) {
        $link = sprintf(
            '<a href="%s" rel="external nofollow" class="url">%s</a>',
            get_author_posts_url( $comment->user_id ),
            strip_tags( $link )
        );
    }
    return $link;
}

if ( ! function_exists( 'kryex_comments' ) ) {
  function kryex_comments($comment, $args, $depth) {
    $GLOBALS['comment'] = $comment;

    $comment_class = 'comment-body';
    $comment_class .= empty( $args['has_children'] ) ? '' : ' ' . 'parent'; ?>

    <div id="comment-<?php comment_ID(); ?>" class="comment-article">
        <header class="comment-author clear-fix">
          <div class="com_left">
            <div class="comment-avatar"><?php echo get_avatar( get_comment_author_email(), 150 ); ?></div>
          </div>
          <div class="com_right">
            <?php printf('<span class="comment-author-name">%s</span>', get_comment_author_link()); ?>

            <div class="comment-text">
                <?php if ($comment->comment_approved == '0') : ?>
                <div class="alert info">
                    <p><?php _e('Yorumunuz onay bekliyor.', KRYEX_TEXT ) ?></p>
                </div>
                <?php endif; ?>
                <section class="comment-content">
                    <?php comment_text() ?>
                </section>
            </div>

            <div class="com_meta">
              <span class="comment-time" datetime="<?php comment_time('c'); ?>"><?php comment_time(__('j F Y ', KRYEX_TEXT )); ?> </span>
              <span class="comment-links">
                <?php edit_comment_link();
                comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))); ?>
              </span>
            </div>
          </div>
        </header>
    </div><?php

    }
}

//Comment Form Fields
function kryex_comment_form_fields( $fields ) {
  $commenter = wp_get_current_commenter();

  $req      = get_option( 'require_name_email' );
  $aria_req = ( $req ? " aria-required='true'" : '' );

  global $kryex;
  
  $langname = $kryex['lang_name'];
  $langemail = $kryex['lang_email'];

  $fields =  array(

    'author' =>
      '<div class="cmX"><div class="form-group comment-form-author"> ' .
      '<input id="author" class="form_control" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) .
      '" size="30"' . $aria_req . ' placeholder="'.$langname.'" required/></div>',

    'email' =>
      '<div class="form-group comment-form-email">' .
      '<input id="email" class="form_control" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) .
      '" size="30"' . $aria_req . ' placeholder="'.$langemail.'" required/></div></div>',

  );

  return $fields;
}

add_filter( 'comment_form_default_fields', 'kryex_comment_form_fields' );

function comment_form_change_cookies_consent( $fields ) {
  $commenter = wp_get_current_commenter();
  $consent   = empty( $commenter['comment_author_email'] ) ? '' : ' checked="checked"';
  $fields['cookies'] = '<p class="comment-form-cookies-consent"><input id="wp-comment-cookies-consent" name="wp-comment-cookies-consent" type="checkbox" value="yes"' . $consent . ' />' .
           '<label for="wp-comment-cookies-consent">'.esc_html__(' Email adresimi tarayıcıya kaydet', KRYEX_TEXT ).'</label></p>';
  return $fields;
}
add_filter( 'comment_form_default_fields', 'comment_form_change_cookies_consent' );


/* Post media function
==================================================
*/

function kryex_get_embedded_media( $type = array() ){
  $content = do_shortcode( apply_filters( 'the_content', get_the_content() ) );
  $embed = get_media_embedded_in_content( $content, $type );

  if ( in_array( 'audio', $type ) ):
    $output = str_replace( '?visual=true', '?visual=false', $embed[0] );
  else:
    $output = $embed[0];
  endif;

  return $output;
}

/* MEDİA POST FORMAT
==================================================
*/

function Kryex_galleryToCarousel( $content ) {

  global $post;

  // Make sure the post format is gallery
  if ( !has_post_format( 'gallery' ) )
    return $content;

  // Make sure the post has a gallery in it
  if ( !has_shortcode( $post->post_content, 'gallery' ) )
    return $content;

  // Retrieve the galleries in the post
  $galleries = get_post_galleries_images( $post );

  $the_d = get_the_ID();
  $i = 0;
  $image_list = '<div id="post-gallery-'.$the_d.'" class="carousel"><ul id="carousel_inner" class="carousel-inner" role="listbox">';

  // Loop through all galleries found
  foreach( $galleries as $gallery ) {

    // Loop through each image in each gallery
    foreach( $gallery as $image_url ) {
      $i++;
      $active = ( $i == 1 ? ' active' : '' );
        $image_list .= '<li id="imagx-'.$i.'" class="carousel-item'.$active.'"><a href="'.esc_url( $image_url ).'" data-fancybox="SliderResim"><div id="slid-'.$i.'" class="image-sliD lazyload" role="img" data-bgset="'.esc_url( $image_url ).'"></div></a></li>';
      
    }

  }

  $image_list .= '</ul>';

  $image_list .= '<a id="sControl1" class="scon prev"><i class="icofont-rounded-left"></i></a>';

  $image_list .= '<a id="sControl2" class="scon next"><i class="icofont-rounded-right"></i></a>';

  $image_list .= '</div>';



  return $image_list;

}


/* Breadcrumbs function
==================================================
*/

if( ! function_exists( 'kryex_breadcrumbs' )){

  function kryex_breadcrumbs(){

    global $kryex;
    $bread_home = $kryex['bread_home'];
    
    // breadcrumbs
    $delimiter   = '<i class="icofont-rounded-double-right" aria-hidden="true"></i>';
    $delimiter   = '<em class="delimiter">'. $delimiter .'</em>';
    $home_icon   = '<span class="icofont-home"></span>';
    $home_text   = $bread_home;
    $before      = '<span class="xx current">';
    $after       = '</span>';
    $breadcrumbs = array();

    // bbPress breadcrumbs
    if  ( ! is_home() && ! is_front_page() || is_paged() ){

      $post     = get_post();
      $home_url = esc_url(home_url( '/' ));

      // Home
      $breadcrumbs[] = array(
        'url'   => $home_url,
        'name'  => $home_text,
        'icon'  => $home_icon,
      );

      // Category
      if ( is_category() ){

        $category = get_query_var( 'cat' );
        $category = get_category( $category );

        if( $category->parent !== 0 ){

          $parent_categories = array_reverse( get_ancestors( $category->cat_ID, 'category' ) );

          foreach ( $parent_categories as $parent_category ) {
            $breadcrumbs[] = array(
              'url'  => get_term_link( $parent_category, 'category' ),
              'name' => get_cat_name( $parent_category ),
            );
          }
        }

        $breadcrumbs[] = array(
          'name' => get_cat_name( $category->cat_ID ),
        );
      }

      // Day
      elseif ( is_day() ){

        $breadcrumbs[] = array(
          'url'  => get_year_link( get_the_time( 'Y' ) ),
          'name' => get_the_time( 'Y' ),
        );

        $breadcrumbs[] = array(
          'url'  => get_month_link( get_the_time( 'Y' ), get_the_time( 'm' ) ),
          'name' => get_the_time( 'F' ),
        );

        $breadcrumbs[] = array(
          'name' => get_the_time( 'd' ),
        );
      }

      // Month
      elseif ( is_month() ){

        $breadcrumbs[] = array(
          'url'  => get_year_link( get_the_time( 'Y' ) ),
          'name' => get_the_time( 'Y' ),
        );

        $breadcrumbs[] = array(
          'name' => get_the_time( 'F' ),
        );
      }

      // Year
      elseif ( is_year() ){

        $breadcrumbs[] = array(
          'name' => get_the_time( 'Y' ),
        );
      }

      // Tag
      elseif ( is_tag() ){

        $breadcrumbs[] = array(
          'name' => get_the_archive_title(),
        );
      }

      // Author
      elseif ( is_author() ){

        global $author, $kryex;
        
        $autLinkBr = $kryex['Aut_br_link'];
        $autTextBr = $kryex['Aut_br_text'];
        $curauth   = (isset($_GET['author_name'])) ? get_user_by('slug', $author_name) : get_userdata(intval($author));

        $breadcrumbs[] = array(
          'name' => '<a href="'.get_option('home').'/'.$autLinkBr.'/"> '.$autTextBr.' </a>'.$delimiter.'<span class="br-title">'.$curauth->display_name.'</span>',
        );
      }

      // Search
      elseif ( is_search() ){

        $breadcrumbs[] = array(
          'name' => sprintf( esc_html__( 'Arama Sonuçları: %s', KRYEX_TEXT ),  get_search_query() ),
        );
      }

      // 404
      elseif ( is_404() ){

        $breadcrumbs[] = array(
          'name' => esc_html__( 'Hiçbirşey Bulunamadı', KRYEX_TEXT ),
        );
      }

      // BuddyPress
      elseif ( function_exists('bp_current_component') && bp_current_component() ){

        $breadcrumbs[] = array(
          'name' => get_the_title(),
        );
      }

      // Pages
      elseif ( is_page() ){

        if ( $post->post_parent ){

          $parent_id   = $post->post_parent;
          $page_parents = array();

          while ( $parent_id ){
            $get_page  = get_page( $parent_id );
            $parent_id = $get_page->post_parent;

            $page_parents[] = array(
              'url'  => get_permalink( $get_page->ID ),
              'name' => get_the_title( $get_page->ID ),
            );
          }

          $page_parents = array_reverse( $page_parents );

          foreach( $page_parents as $single_page ){

            $breadcrumbs[] = array(
              'url'  => $single_page['url'],
              'name' => $single_page['name'],
            );
          }
        }

        $breadcrumbs[] = array(
          'name' => get_the_title(),
        );
      }

      // Attachment
      elseif ( is_attachment() ){

        if( ! empty( $post->post_parent ) ){
          $parent = get_post( $post->post_parent );

          $breadcrumbs[] = array(
            'url'  => get_permalink( $parent ),
            'name' => $parent->post_title,
          );
        }

        $breadcrumbs[] = array(
          'name' => get_the_title(),
        );
      }

      // Single Posts
      elseif ( is_singular() ){

        // Single Post
        if ( get_post_type() == 'post' ){

          $category = get_the_category();
          $useCatLink = true;
          // If post has a category assigned.
          if ($category){
              $category_display = '';
              $category_link = '';
              if ( class_exists('WPSEO_Primary_Term') ) {
                  // Show the post's 'Primary' category, if this Yoast feature is available, & one is set
                  $wpseo_primary_term = new WPSEO_Primary_Term( 'category', get_the_id() );
                  $wpseo_primary_term = $wpseo_primary_term->get_primary_term();
                  $term = get_term( $wpseo_primary_term );
                  if (is_wp_error($term)) { 
                      // Default to first category (not Yoast) if an error is returned
                      $category_display = $category[0]->name;
                      $category_link = get_category_link( $category[0]->term_id );
                  } else { 
                      // Yoast Primary category
                      $category_display = $term->name;
                      $category_link = get_category_link( $term->term_id );
                  }
              } 
              else {
                  // Default, display the first category in WP's list of assigned categories
                  $category_display = $category[0]->name;
                  $category_link = get_category_link( $category[0]->term_id );
              }
              
          }

          if( ! empty( $category ) ){

            $category = get_category( $category );

            if( $category->parent !== 0 ){
              $parent_categories = array_reverse( get_ancestors( $category->term_id, 'category' ) );

              foreach ( $parent_categories as $parent_category ) {
                $breadcrumbs[] = array(
                  'url'  => $category_link,
                  'name' => htmlspecialchars($category_display),
                );
              }
            }

            $breadcrumbs[] = array(
              'url'  => $category_link,
              'name' => htmlspecialchars($category_display),
            );
          }
        }

        // Custom Post Type
        else{

          // Get the main Post type archive link
          if( $archive_link = get_post_type_archive_link( get_post_type() ) ){

            $post_type = get_post_type_object( get_post_type() );

            $breadcrumbs[] = array(
              'url'  => $archive_link,
              'name' => $post_type->labels->singular_name,
            );
          }

          // Get custom Post Types taxonomies
          $taxonomies = get_object_taxonomies( $post, 'objects' );

          if( ! empty( $taxonomies ) && is_array( $taxonomies ) ){
            foreach( $taxonomies as $taxonomy ){
              if( $taxonomy->hierarchical ){
                $taxonomy_name = $taxonomy->name;
                break;
              }
            }
          }

          if( ! empty( $taxonomy_name ) ){
            $custom_terms = get_the_terms( $post, $taxonomy_name );

            if( ! empty( $custom_terms ) && ! is_wp_error( $custom_terms )){

              foreach ( $custom_terms as $term ){

                $breadcrumbs[] = array(
                  'url'  => get_term_link( $term ),
                  'name' => $term->name,
                );

                break;
              }
            }
          }
        }

        $breadcrumbs[] = array(
          'name' => get_the_title(),
        );
      }


      // Print the BreadCrumb
      if( ! empty( $breadcrumbs ) ){

        $counter = 0;
        $item_list_elements = array();
        $breadcrumbs_schema = array(
          '@context' => 'http://schema.org',
          '@type'    => 'BreadcrumbList',
          '@id'      => '#Breadcrumb',
        );

        echo '<nav class="breadcrumb">';

          foreach( $breadcrumbs as $item ) {

            $counter++;

            if( ! empty( $item['url'] )){
              $icon = ! empty( $item['icon'] ) ? $item['icon'] .' ' : '';
              echo '<a href="'. esc_url( $item['url'] ) .'">'. $icon . $item['name'] .'</a>'. $delimiter;
            }
            else{
              echo ( $before . $item['name'] . $after );

              global $wp;
              $item['url'] = esc_url(home_url(add_query_arg(array(),$wp->request)));
            }

            $item_list_elements[] = array(
              '@type'    => 'ListItem',
              'position' => $counter,
              'item'     => array(
                'name' => str_replace( '<span class="fa fa-home ss" aria-hidden="true"></span> ', '', $item['name']),
                '@id'  => $item['url'],
              )
            );

          }

        echo '</nav>';
      }
    }

    wp_reset_postdata();
  }

}


/* tag display
==================================================
*/

function kryex_tag_cloud_font_change( $args ){
    $args['smallest'] = 8;
    $args['largest']  = 8;
    $args['format']  = 'list';

    return $args;
}
add_filter( 'widget_tag_cloud_args', 'kryex_tag_cloud_font_change' );

function kryex_list_categories_output_change( $links ) {
    
    $links = str_replace('</a> (', '</a> <span>', $links);
    $links = str_replace(')', '</span>', $links);
    
    return $links;
    
}
add_filter( 'wp_list_categories', 'kryex_list_categories_output_change' );
