<?php

/**
 * Kryex Nano widgets
 * @package  Kryex Themes
 */

defined( 'ABSPATH' ) || exit; // Exit if accessed directly


/*
==========================================
    SİDEBAR POSTS
==========================================
*/

class Kryex_Category_List extends WP_Widget {

    // Sets up a new widget instance.
    public function __construct() {

        $this->default_settings = apply_filters( 'category_list_settings', array(
            'title'     => esc_html__( 'Kategoriler', KRYEX_TEXT ),
        ));

        $widget_details = array(
            'classname'   => 'category_list_widget',
            'description' => 'Resimli slider kategori listesi',
        );

        parent::__construct( 'kryex_category_list', esc_html__( '* Kategoriler', KRYEX_TEXT ), $widget_details );
    }

    // Outputs the content for the current widget instance.
    public function widget( $args, $instance ) {

        $params = array_merge( $this->default_settings, $instance );

        // Title.
        if ( $params['title'] ) {
            $params['widget_title'] = $args['before_title'] . apply_filters( 'widget_title', $params['title'], $instance, $this->id_base ) . $args['after_title'];
        }

        // Before Widget.
        echo $args['before_widget']; ?>
            <div id="section-category-list">
                <div class="section_title">
                    <?php
                        // Title.
                        if ( isset( $params['widget_title'] ) && $params['widget_title'] ) {
                            echo wp_kses_post( apply_filters( 'widget_about_title', $params['widget_title'], $params['title'] ) );
                        }

                    ?>
                    <div class="catNavigation">
                        <span class="cat_prev"><i class="icofont-rounded-double-left"></i></span><span class="cat_next"><i class="icofont-rounded-double-right"></i></span>
                    </div>
                </div>
                <div class="catSlider wh_bg">
                    <div class="swiper-wrapper" role="listbox">
                        <?php global $kryex;

                            $order      = $kryex['catlist_order'];
                            $orderby    = $kryex['catlist_orderby'];
                            $categories = get_categories( array(
                                'orderby' => $orderby,
                                'order'   => $order
                            ));
                             
                            foreach( $categories as $category ) {
                                $category_link = sprintf( 
                                    '<h5 class="category_title"><a href="%1$s" tabindex="0">%3$s</a></h5>',
                                    esc_url( get_category_link( $category->term_id ) ),
                                    esc_attr( sprintf( __( '%s kategorisindeki yazıları gör', KRYEX_TEXT ), $category->name ) ),
                                    esc_html( $category->name )
                                ); $image_id = get_term_meta ( $category->cat_ID, 'category-image-id', true ); ?>

                                <div class="swiper-slide scl">
                                    <?php

                                        if (!empty($image_id)) {
                                            echo '<div class="category_list scale lazyload" role="img" data-bgset="'.wp_get_attachment_image_url ( $image_id, 'large' ).'"></div>';
                                        } else {
                                            echo '<div class="category_list scale" style="background:url('.esc_url( KRYEX_THEME_URI ).'/img/nothumb.jpg) no-repeat center center / cover;"></div>';
                                        }

                                        echo '<a class="thumb_link" href="'.sprintf( esc_url( get_category_link( $category->term_id ) ) ).'" aria-label="'.esc_attr( sprintf( __( '%s kategorisindeki yazıları gör', KRYEX_TEXT ), $category->name ) ).'" tabindex="0"></a>';

                                        echo '<div class="category_wrapper">' . sprintf( esc_html__( '%s', KRYEX_TEXT ), $category_link ) . '<p>'.sprintf( $category->count ) .' '. $kryex['aut_list_postText'].'</p></div>';

                                    ?>
                                </div><?php
                            }
                        ?>
                    </div>
                </div>
            </div>
        <?php
        // After Widget.
        echo $args['after_widget'];
    }

    // Handles updating settings for the current widget instance.
    public function update( $new_instance, $old_instance ) {
        $instance                   = $new_instance;
        $instance['title']          = sanitize_text_field( $new_instance['title'] );

        return $instance;
    }

    // Outputs the widget settings form.
    public function form( $instance ) {
        $params = array_merge( $this->default_settings, $instance ); ?>

        <!-- Title -->
        <p><label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Başlık', KRYEX_TEXT ); ?></label>
        <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $params['title'] ); ?>" /></p>

        <!-- Title -->
        <p>Kategorilerin listeleneceği bir slider alanı ekler. <br><br> Daha fazla ayar için <b>Tema Ayarları > Blog Ayarları'</b>na gidin</p>

        <?php
    }

}

add_action( 'widgets_init', function() {
    register_widget( 'Kryex_Category_List' );
});