<?php

/**
 * Kryex Nano widgets
 * @package  Kryex Themes
 */

defined( 'ABSPATH' ) || exit; // Exit if accessed directly


/*
==========================================
    HOME POSTS
==========================================
*/

class Kryex_Featured_Column_News extends WP_Widget {

    public function __construct() {

        $this->default_settings = apply_filters( 'kryex_featured_settings', array(
            'title'     => esc_html__( 'Blog Post 1', KRYEX_TEXT ),
            'iconx'     => 'fa-bookmark'
        ));

        $widget_details = array(
            'classname'   => 'kryex_featured_widget',
            'description' => esc_html__( 'Blog yazıları stil 1', KRYEX_TEXT ),
        );

        parent::__construct( 'kryex_featured_posts', esc_html__( '* Blog Post 1', KRYEX_TEXT ), $widget_details );
    }

    function widget( $args, $instance ) {
        
        $title          = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
        $mix_category   = ! empty( $instance['mix_category'] ) ? $instance['mix_category'] : 0;
        $view_all_text  = ! empty( $instance['view_all_text'] ) ? $instance['view_all_text'] : '';
        $iconx          = ! empty( $instance['iconx'] ) ? $instance['iconx'] : 'fa-bookmark';
        $post_number    = ! empty( $instance['post_number'] ) ? $instance['post_number'] : 6;
        $posts_order    = ! empty( $instance['posts_order'] )   ? $instance['posts_order'] : 'latest';

        echo $args['before_widget'];

        if( !empty( $instance[ 'title' ] ) ): ?>

        <div class="section_title">
            <h3 class="widgettitle"><i class="<?php echo $iconx; ?>"></i>  <?php echo apply_filters( 'widget_title', $instance[ 'title' ] ) ?></h3>
            <?php
                if( ! empty( $view_all_text ) ) :

                    if ( absint( $mix_category ) > 0 ) {
                        $cat_link = get_category_link( $mix_category );
                    } else {
                        $cat_link = '';
                    }

                    echo '<a class="view_all blog" href="'.esc_url( $cat_link ).'" title="'.esc_html( $view_all_text ).'">'.esc_html( $view_all_text ).'</a>';

                endif;
            ?>
        </div>
        <?php endif; ?>
        <ul class="row posts-list-items">
            <?php

            if( $posts_order == '_post_like_count' ) :
                $postPop = esc_attr( '_post_like_count' );
            else :
                $postPop = esc_attr( 'post_views_count' );
            endif;

            $mix_args = array(
                'posts_per_page'        => absint( $post_number ),
                'no_found_rows'         => true,
                'post__not_in'          => get_option( 'sticky_posts' ),
                'ignore_sticky_posts'   => true,
                'meta_key'              => $postPop,
                'orderby'               => $posts_order,
                'order'                 => 'DESC'
            );

            if ( absint( $mix_category ) > 0 ) {
                $mix_args['cat'] = absint( $mix_category );
            }

            $mix_posts = new WP_Query( $mix_args );

            if( $mix_posts->have_posts() ):
                while( $mix_posts->have_posts() ): $mix_posts->the_post();
                        global $kryex;

                        if ( has_post_format('gallery') ) {
                            $iconFormat  = '<i class="icoX icofont-instagram"></i>';
                        } else if ( has_post_format('video') ) {
                            $iconFormat  = '<i class="icoX icofont-ui-play"></i>';
                        } else {
                            $iconFormat  = '';
                        }
                    ?>
                    <li class="col-xl-6 col-md-6 col-6 widget-post">
                        <div class="wh_bg">
                            <a class="post_thumb" href="<?php the_permalink(); ?>">
                                <?php echo $iconFormat;
                                    if (has_post_thumbnail()) :
                                        the_post_thumbnail( 'thumb_post', array( 'alt' => get_the_title() ));
                                    else :
                                        echo '<div class="no_thumb" style="background-image: url('.esc_url( KRYEX_THEME_URI ).'/img/nothumb.jpg);"></div>';
                                    endif;
                                ?>
                            </a>
                            <h2 class="post-title">
                                <a href="<?php echo get_the_permalink(); ?>" title="<?php echo get_the_title(); ?>"><?php echo get_the_title(); ?></a>
                            </h2>
                            <div class="post_overlay">
                                <span class="post_date">
                                    <?php
                                        if( $kryex['date_format'] == '1' ) :
                                            echo get_the_date();
                                        else :
                                            echo meks_time_ago();
                                        endif;
                                    ?>
                                </span>
                                <?php
                                    if ( $posts_order == '_post_like_count' ) :
                                        echo '<span class="xpan likes">'.get_simple_likes_button(get_the_ID()).'</span>';
                                    elseif ( $posts_order == 'comment_count' ) :
                                        echo '<span class="xpan comments">'.kryex_posted_comments().'</span>';
                                    else :
                                        echo '<span class="xpan views" title="'.$kryex['goruntulenme'].'"><i class="icofont-fire-burn"></i>'.getPostViews(get_the_ID()).'</span>';
                                    endif;
                                ?>
                            </div>
                        </div>
                    </li>

                <?php
                endwhile;
                wp_reset_postdata();
            endif; ?>
        </ul>

        <?php echo $args['after_widget'];
    }

    function update( $new_instance, $old_instance ) {
        $instance                   = $old_instance;
        $instance['title']          = sanitize_text_field( $new_instance['title'] );
        $instance['mix_category']   = absint( $new_instance['mix_category'] );
        $instance['view_all_text']  = sanitize_text_field( $new_instance['view_all_text'] );
        $instance['iconx']          = sanitize_text_field( $new_instance['iconx'] );
        $instance['post_number']    = absint( $new_instance['post_number'] );
        $instance['posts_order']    = $new_instance['posts_order'];

        return $instance;
    }

    function form( $instance ) {

        $instance = wp_parse_args( (array) $instance, array(
            'title'             => '',
            'iconx'             => '',
            'mix_category'      => '',
            'view_all_text'     => esc_html__( 'Tümünü Gör', KRYEX_TEXT ),
            'post_number'       => 6,

        ));

        $iconx          = esc_attr( $instance[ 'iconx' ] );
        $posts_order    = ! empty( $instance['posts_order'] ) ? $instance['posts_order'] : 'latest';

        // Post Order : Default
        $post_order = array(
            'standard' => array(
                'latest'            => esc_html__( 'En son yazılar',            KRYEX_TEXT ),
                'rand'              => esc_html__( 'Rastgele yazılar',          KRYEX_TEXT ),
                'comment_count'     => esc_html__( 'En çok yorumlananlar',      KRYEX_TEXT ),
                'meta_value_num'    => esc_html__( 'En çok görüntülenenler',    KRYEX_TEXT ),
                '_post_like_count'  => esc_html__( 'En çok beğenilenler',       KRYEX_TEXT ),
            ),
        );

        ?>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Düzen:', KRYEX_TEXT ); ?></label>
            <img src="<?php echo get_template_directory_uri(); ?>/img/nx_style1.jpg" class="layout-img">
        </p>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Başlık:', KRYEX_TEXT ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['title'] ); ?>" />
        </p>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'iconx' ) ); ?>"><strong><?php esc_html_e( 'Başlık ikonu:', KRYEX_TEXT ); ?></strong></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'iconx' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'iconx' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['iconx'] ); ?>" />
            <small>
                <?php esc_html_e('örnek: icofont-contacts', KRYEX_TEXT); ?>
            </small>
        </p>
        
        <p>
          <label for="<?php echo  esc_attr( $this->get_field_id( 'mix_category' ) ); ?>"><strong><?php esc_html_e( 'Kategori:', KRYEX_TEXT ); ?></strong></label>
            <?php
                $cat_args = array(
                    'orderby'         => 'name',
                    'hide_empty'      => 0,
                    'class'           => 'widefat',
                    'taxonomy'        => 'category',
                    'name'            => $this->get_field_name( 'mix_category' ),
                    'id'              => $this->get_field_id( 'mix_category' ),
                    'selected'        => absint( $instance['mix_category'] ),
                    'show_option_all' => esc_html__( 'Tüm Kategoriler', KRYEX_TEXT ),
                );
                wp_dropdown_categories( $cat_args );
            ?>
        </p>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'posts_order' ) ); ?>"><?php esc_html_e( 'Yazıları Sırala:', KRYEX_TEXT ) ?></label>
            <select id="<?php echo esc_attr( $this->get_field_id( 'posts_order' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'posts_order' ) ); ?>" class="widefat">
                <?php
                    foreach( $post_order as $order_groups => $options ) :
                        echo '<optgroup>';
                            foreach( $options as $order => $text ){ ?>
                                <option value="<?php echo esc_attr( $order ) ?>" <?php selected( $posts_order, $order ); ?>><?php echo esc_attr( $text ) ?></option>
                                <?php
                            }
                        echo '</optgroup>';
                    endforeach;
                ?>
            </select>
        </p>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'view_all_text' ) ); ?>"><strong><?php esc_html_e( 'Tümünü Gör Linki:', KRYEX_TEXT ); ?></strong></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'view_all_text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'view_all_text' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['view_all_text'] ); ?>" />
            <small>
                <?php esc_html_e('Görünmesini istemiyorsanız bu alanı boş bırakın.', KRYEX_TEXT); ?>   
            </small>
        </p>

        <p>
          <label for="<?php echo esc_attr( $this->get_field_id( 'post_number' ) ); ?>"><strong><?php esc_html_e( 'Yazı sayısı:', KRYEX_TEXT ); ?></strong></label>
            <?php
                $this->dropdown_post_number( array(
                    'id'       => $this->get_field_id( 'post_number' ),
                    'name'     => $this->get_field_name( 'post_number' ),
                    'selected' => absint( $instance['post_number'] ),
                    )
                );
            ?>
        </p>
       
        <?php
    }

    function dropdown_post_number( $args ) {
        $defaults = array(
            'id'       => '',
            'name'     => '',
            'selected' => 0,
        );

        $r = wp_parse_args( $args, $defaults );
        $output = '';

        $choices = array(
            '1' => 1,
            '2' => 2,
            '3' => 3,
            '4' => 4,
            '5' => 5,
            '6' => 6,
            '7' => 7,
            '8' => 8,
            '9' => 9,
            '10' => 10,
            '11' => 11,
            '12' => 12,
        );

        if ( ! empty( $choices ) ) {

            $output = "<select name='" . esc_attr( $r['name'] ) . "' id='" . esc_attr( $r['id'] ) . "'>\n";
            foreach ( $choices as $key => $choice ) {
                $output .= '<option value="' . esc_attr( $key ) . '" ';
                $output .= selected( $r['selected'], $key, false );
                $output .= '>' . esc_html( $choice ) . '</option>\n';
            }
            $output .= "</select>\n";
        }

        echo $output;
    }

}

add_action( 'widgets_init', function() {
    register_widget( 'Kryex_Featured_Column_News' );
});

