<?php

/**
 * Kryex Nano widgets
 * @package  Kryex Themes
 */

defined( 'ABSPATH' ) || exit; // Exit if accessed directly


/*
==========================================
    SİDEBAR POSTS
==========================================
*/

class Kryex_Last_Posts extends WP_Widget {

    // Sets up a new widget instance.
    public function __construct() {

        $this->default_settings = apply_filters( 'last_posts_settings', array(
            'title'     => esc_html__( 'Tüm Yazılar Alanı', KRYEX_TEXT ),
        ));

        $widget_details = array(
            'classname'   => 'last_posts_widget',
            'description' => 'Tüm yazıların listelendiği bileşen',
        );

        parent::__construct( 'kryex_last_post', esc_html__( '* Tüm Yazılar Alanı', KRYEX_TEXT ), $widget_details );
    }

    // Outputs the content for the current widget instance.
    public function widget( $args, $instance ) {

        $params = array_merge( $this->default_settings, $instance );

        // Title.
        if ( $params['title'] ) {
            $params['widget_title'] = $args['before_title'] . apply_filters( 'widget_title', $params['title'], $instance, $this->id_base ) . $args['after_title'];
        }

        // Before Widget.
        echo $args['before_widget']; ?>
            <div id="section-last-posts">
                <div class="kryex_pagination">
                    <div class="section_title">
                        <?php
                            // Title.
                            if ( isset( $params['widget_title'] ) && $params['widget_title'] ) {
                                echo wp_kses_post( apply_filters( 'widget_about_title', $params['widget_title'], $params['title'] ) );
                            }

                        ?>
                    </div>
                    <ul class="last-post-items">
                        <?php 
                            if( have_posts() ):
                                while( have_posts() ): the_post();
                                    get_template_part( 'template-parts/last-content', get_post_format() );
                                endwhile;
                                wp_reset_postdata();
                            endif;
                        ?>
                    </ul>
                    <div class="post-pagination text-center">
                        <?php the_posts_pagination(array(
                            'prev_text' => '<i class="icofont-rounded-double-left"></i>',
                            'next_text' => '<i class="icofont-rounded-double-right"></i>',
                            'type' => 'list',
                            'screen_reader_text' => '',
                        )); ?>
                    </div>
                </div>
            </div>
        <?php
        // After Widget.
        echo $args['after_widget'];
    }

    // Handles updating settings for the current widget instance.
    public function update( $new_instance, $old_instance ) {
        $instance           = $new_instance;
        $instance['title']  = sanitize_text_field( $new_instance['title'] );

        return $instance;
    }

    // Outputs the widget settings form.
    public function form( $instance ) {
        $params = array_merge( $this->default_settings, $instance ); ?>

        <!-- Title -->
        <p><label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Başlık', KRYEX_TEXT ); ?></label>
        <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $params['title'] ); ?>" /></p>

        <!-- Title -->
        <p>Tüm yazıların listelendiği bileşen alanı</p>

        <?php
    }

}

add_action( 'widgets_init', function() {
    register_widget( 'Kryex_Last_Posts' );
});