<?php
    /**
     * ReduxFramework Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

    // This is your option name where all the Redux data is stored.
    $opt_name = "kryex";

    // This line is only for altering the demo. Can be easily removed.
    $opt_name = apply_filters( 'redux_demo/opt_name', $opt_name );

    /*
     *
     * --> Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
     *
     */

    $sampleHTML = '';
    if ( file_exists( dirname( __FILE__ ) . '/info-html.html' ) ) {
        Redux_Functions::initWpFilesystem();

        global $wp_filesystem;

        $sampleHTML = $wp_filesystem->get_contents( dirname( __FILE__ ) . '/info-html.html' );
    }

    // Background Patterns Reader
    $sample_patterns_path = ReduxFramework::$_dir . '../sample/patterns/';
    $sample_patterns_url  = ReduxFramework::$_url . '../sample/patterns/';
    $sample_patterns      = array();
    
    if ( is_dir( $sample_patterns_path ) ) {

        if ( $sample_patterns_dir = opendir( $sample_patterns_path ) ) {
            $sample_patterns = array();

            while ( ( $sample_patterns_file = readdir( $sample_patterns_dir ) ) !== false ) {

                if ( stristr( $sample_patterns_file, '.png' ) !== false || stristr( $sample_patterns_file, '.jpg' ) !== false ) {
                    $name              = explode( '.', $sample_patterns_file );
                    $name              = str_replace( '.' . end( $name ), '', $sample_patterns_file );
                    $sample_patterns[] = array(
                        'alt' => $name,
                        'img' => $sample_patterns_url . $sample_patterns_file
                    );
                }
            }
        }
    }

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => false,
        // Show the sections below the admin menu item or not
        'menu_title'           => __( 'Tema Ayarları', KRYEX_TEXT ),
        'page_title'           => __( 'Tema Ayarları', KRYEX_TEXT ),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => '',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => false,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => false,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-admin-customizer',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => false,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => true,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => 30,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => get_template_directory_uri().'/img/kryex-icon.png',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => '',
        // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => true,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        'footer_credit'     => 'Powered by <a href="https://www.kryextheme.site" target="_blank">Kryex Theme</a>',

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
        'use_cdn'              => true,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'red',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    // ADMIN BAR LINKS -> Setup custom links in the admin bar menu as external items.
/*    $args['admin_bar_links'][] = array(
        'id'    => 'redux-docs',
        'href'  => 'http://docs.reduxframework.com/',
        'title' => __( 'Documentation', KRYEX_TEXT ),
    );

    $args['admin_bar_links'][] = array(
        //'id'    => 'redux-support',
        'href'  => 'https://github.com/ReduxFramework/redux-framework/issues',
        'title' => __( 'Support', KRYEX_TEXT ),
    );

    $args['admin_bar_links'][] = array(
        'id'    => 'redux-extensions',
        'href'  => 'reduxframework.com/extensions',
        'title' => __( 'Extensions', KRYEX_TEXT ),
    );*/

    // SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
    
    $args['share_icons'][] = array(
        'url'   => 'https://www.facebook.com/kryextheme',
        'title' => 'Like us on Facebook',
        'icon'  => 'el el-facebook'
    );
    $args['share_icons'][] = array(
        'url'   => 'http://twitter.com/kryextheme',
        'title' => 'Follow us on Twitter',
        'icon'  => 'el el-twitter'
    );
    

    // Panel Intro text -> before the form
    if ( ! isset( $args['global_variable'] ) || $args['global_variable'] !== false ) {
        if ( ! empty( $args['global_variable'] ) ) {
            $v = $args['global_variable'];
        } else {
            $v = str_replace( '-', '_', $args['opt_name'] );
        }
        $args['intro_text'] = sprintf( __( '', KRYEX_TEXT ), $v );
    } else {
        $args['intro_text'] = __( '', KRYEX_TEXT );
    }

    // Add content after the form.
    $args['footer_text'] = __( '', KRYEX_TEXT );

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */


    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => __( 'Theme Information 1', KRYEX_TEXT ),
            'content' => __( '<p>This is the tab content, HTML is allowed.</p>', KRYEX_TEXT )
        ),
        array(
            'id'      => 'redux-help-tab-2',
            'title'   => __( 'Theme Information 2', KRYEX_TEXT ),
            'content' => __( '<p>This is the tab content, HTML is allowed.</p>', KRYEX_TEXT )
        )
    );
    Redux::setHelpTab( $opt_name, $tabs );

    // Set the help sidebar
    $content = __( '<p>This is the sidebar content, HTML is allowed.</p>', KRYEX_TEXT );
    Redux::setHelpSidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */

    $icons = array("fa-adjust", "fa-adn", "fa-align-center", "fa-align-justify", "fa-align-left", "fa-align-right", "fa-ambulance", "fa-anchor", "fa-android", "fa-angellist", "fa-angle-double-down", "fa-angle-double-left", "fa-angle-double-right", "fa-angle-double-up", "fa-angle-down", "fa-angle-left", "fa-angle-right", "fa-angle-up", "fa-apple", "fa-archive", "fa-area-chart", "fa-arrow-circle-down", "fa-arrow-circle-left", "fa-arrow-circle-o-down", "fa-arrow-circle-o-left", "fa-arrow-circle-o-right", "fa-arrow-circle-o-up", "fa-arrow-circle-right", "fa-arrow-circle-up", "fa-arrow-down", "fa-arrow-left", "fa-arrow-right", "fa-arrow-up", "fa-arrows", "fa-arrows-alt", "fa-arrows-h", "fa-arrows-v", "fa-asterisk", "fa-at", "fa-automobile", "fa-backward", "fa-ban", "fa-bank", "fa-bar-chart", "fa-bar-chart-o", "fa-barcode", "fa-bars", "fa-bed", "fa-beer", "fa-behance", "fa-behance-square", "fa-bell", "fa-bell-o", "fa-bell-slash", "fa-bell-slash-o", "fa-bicycle", "fa-binoculars", "fa-birthday-cake", "fa-bitbucket", "fa-bitbucket-square", "fa-bitcoin", "fa-bold", "fa-bolt", "fa-bomb", "fa-book", "fa-bookmark", "fa-bookmark-o", "fa-briefcase", "fa-btc", "fa-bug", "fa-building", "fa-building-o", "fa-bullhorn", "fa-bullseye", "fa-bus", "fa-buysellads", "fa-cab", "fa-calculator", "fa-calendar", "fa-calendar-o", "fa-camera", "fa-camera-retro", "fa-car", "fa-caret-down", "fa-caret-left", "fa-caret-right", "fa-caret-square-o-down", "fa-caret-square-o-left", "fa-caret-square-o-right", "fa-caret-square-o-up", "fa-caret-up", "fa-cart-arrow-down", "fa-cart-plus", "fa-cc", "fa-cc-amex", "fa-cc-discover", "fa-cc-mastercard", "fa-cc-paypal", "fa-cc-stripe", "fa-cc-visa", "fa-certificate", "fa-chain", "fa-chain-broken", "fa-check", "fa-check-circle", "fa-check-circle-o", "fa-check-square", "fa-check-square-o", "fa-chevron-circle-down", "fa-chevron-circle-left", "fa-chevron-circle-right", "fa-chevron-circle-up", "fa-chevron-down", "fa-chevron-left", "fa-chevron-right", "fa-chevron-up", "fa-child", "fa-circle", "fa-circle-o", "fa-circle-o-notch", "fa-circle-thin", "fa-clipboard", "fa-clock-o", "fa-close", "fa-cloud", "fa-cloud-download", "fa-cloud-upload", "fa-cny", "fa-code", "fa-code-fork", "fa-codepen", "fa-coffee", "fa-cog", "fa-cogs", "fa-columns", "fa-comment", "fa-comment-o", "fa-comments", "fa-comments-o", "fa-compass", "fa-compress", "fa-connectdevelop", "fa-copy", "fa-copyright", "fa-credit-card", "fa-crop", "fa-crosshairs", "fa-css3", "fa-cube", "fa-cubes", "fa-cut", "fa-cutlery", "fa-dashboard", "fa-dashcube", "fa-database", "fa-dedent", "fa-delicious", "fa-desktop", "fa-deviantart", "fa-diamond", "fa-digg", "fa-dollar", "fa-dot-circle-o", "fa-download", "fa-dribbble", "fa-dropbox", "fa-drupal", "fa-edit", "fa-eject", "fa-eercast", "fa-edge", "fa-ellipsis-h", "fa-ellipsis-v", "fa-empire", "fa-envelope", "fa-envelope-o", "fa-envelope-square", "fa-eraser", "fa-eur", "fa-euro", "fa-exchange", "fa-exclamation", "fa-exclamation-circle", "fa-exclamation-triangle", "fa-expand", "fa-external-link", "fa-external-link-square", "fa-eye", "fa-eye-slash", "fa-eyedropper", "fa-facebook", "fa-facebook-f", "fa-facebook-official", "fa-facebook-square", "fa-fast-backward", "fa-fast-forward", "fa-fax", "fa-female", "fa-fighter-jet", "fa-file", "fa-file-archive-o", "fa-file-audio-o", "fa-file-code-o", "fa-file-excel-o", "fa-file-image-o", "fa-file-movie-o", "fa-file-o", "fa-file-pdf-o", "fa-file-photo-o", "fa-file-picture-o", "fa-file-powerpoint-o", "fa-file-sound-o", "fa-file-text", "fa-file-text-o", "fa-file-video-o", "fa-file-word-o", "fa-file-zip-o", "fa-files-o", "fa-film", "fa-filter", "fa-fire", "fa-firefox", "fa-fire-extinguisher", "fa-flag", "fa-flag-checkered", "fa-flag-o", "fa-flash", "fa-flask", "fa-flickr", "fa-floppy-o", "fa-folder", "fa-folder-o", "fa-folder-open", "fa-folder-open-o", "fa-font", "fa-forumbee", "fa-forward", "fa-foursquare", "fa-frown-o", "fa-futbol-o", "fa-gamepad", "fa-gavel", "fa-gbp", "fa-ge", "fa-gear", "fa-gears", "fa-genderless", "fa-gift", "fa-git", "fa-git-square", "fa-github", "fa-github-alt", "fa-github-square", "fa-gittip", "fa-glass", "fa-globe", "fa-google", "fa-google-plus", "fa-google-plus-square", "fa-google-wallet", "fa-graduation-cap", "fa-gratipay", "fa-group", "fa-h-square", "fa-hacker-news", "fa-hand-o-down", "fa-hand-o-left", "fa-hand-o-right", "fa-hand-o-up", "fa-hdd-o", "fa-header", "fa-headphones", "fa-heart", "fa-heart-o", "fa-heartbeat", "fa-history", "fa-home", "fa-hospital-o", "fa-hotel", "fa-html5", "fa-ils", "fa-image", "fa-inbox", "fa-indent", "fa-info", "fa-info-circle", "fa-inr", "fa-instagram", "fa-institution", "fa-ioxhost", "fa-italic", "fa-joomla", "fa-jpy", "fa-jsfiddle", "fa-key", "fa-keyboard-o", "fa-krw", "fa-language", "fa-laptop", "fa-lastfm", "fa-lastfm-square", "fa-leaf", "fa-leanpub", "fa-legal", "fa-lemon-o", "fa-level-down", "fa-level-up", "fa-life-bouy", "fa-life-buoy", "fa-life-ring", "fa-life-saver", "fa-lightbulb-o", "fa-line-chart", "fa-link", "fa-linkedin", "fa-linkedin-square", "fa-linux", "fa-list", "fa-list-alt", "fa-list-ol", "fa-list-ul", "fa-location-arrow", "fa-lock", "fa-long-arrow-down", "fa-long-arrow-left", "fa-long-arrow-right", "fa-long-arrow-up", "fa-magic", "fa-magnet", "fa-mail-forward", "fa-mail-reply", "fa-mail-reply-all", "fa-male", "fa-map-marker", "fa-mars", "fa-mars-double", "fa-mars-stroke", "fa-mars-stroke-h", "fa-mars-stroke-v", "fa-maxcdn", "fa-meanpath", "fa-medium", "fa-medkit", "fa-meh-o", "fa-mercury", "fa-microphone", "fa-microphone-slash", "fa-minus", "fa-minus-circle", "fa-minus-square", "fa-minus-square-o", "fa-mobile", "fa-mobile-phone", "fa-money", "fa-moon-o", "fa-mortar-board", "fa-motorcycle", "fa-music", "fa-navicon", "fa-neuter", "fa-newspaper-o", "fa-openid", "fa-outdent", "fa-pagelines", "fa-paint-brush", "fa-paper-plane", "fa-paper-plane-o", "fa-paperclip", "fa-paragraph", "fa-paste", "fa-pause", "fa-paw", "fa-paypal", "fa-pencil", "fa-pencil-square", "fa-pencil-square-o", "fa-phone", "fa-phone-square", "fa-photo", "fa-picture-o", "fa-pie-chart", "fa-pied-piper", "fa-pied-piper-alt", "fa-pinterest", "fa-pinterest-p", "fa-pinterest-square", "fa-plane", "fa-play", "fa-play-circle", "fa-play-circle-o", "fa-plug", "fa-plus", "fa-plus-circle", "fa-plus-square", "fa-plus-square-o", "fa-power-off", "fa-print", "fa-puzzle-piece", "fa-qq", "fa-qrcode", "fa-question", "fa-question-circle", "fa-quote-left", "fa-quote-right", "fa-ra", "fa-random", "fa-rebel", "fa-recycle", "fa-reddit", "fa-reddit-square", "fa-refresh", "fa-remove", "fa-renren", "fa-reorder", "fa-repeat", "fa-reply", "fa-reply-all", "fa-retweet", "fa-rmb", "fa-road", "fa-rocket", "fa-rotate-left", "fa-rotate-right", "fa-rouble", "fa-rss", "fa-rss-square", "fa-rub", "fa-ruble", "fa-rupee", "fa-save", "fa-scissors", "fa-search", "fa-search-minus", "fa-search-plus", "fa-sellsy", "fa-send", "fa-send-o", "fa-server", "fa-share", "fa-share-alt", "fa-share-alt-square", "fa-share-square", "fa-share-square-o", "fa-shekel", "fa-sheqel", "fa-shield", "fa-ship", "fa-shirtsinbulk", "fa-shopping-cart", "fa-sign-in", "fa-sign-out", "fa-signal", "fa-simplybuilt", "fa-sitemap", "fa-skyatlas", "fa-skype", "fa-slack", "fa-sliders", "fa-slideshare", "fa-smile-o", "fa-soccer-ball-o", "fa-sort", "fa-sort-alpha-asc", "fa-sort-alpha-desc", "fa-sort-amount-asc", "fa-sort-amount-desc", "fa-sort-asc", "fa-sort-desc", "fa-sort-down", "fa-sort-numeric-asc", "fa-sort-numeric-desc", "fa-sort-up", "fa-soundcloud", "fa-space-shuttle", "fa-spinner", "fa-spoon", "fa-spotify", "fa-square", "fa-square-o", "fa-stack-exchange", "fa-stack-overflow", "fa-star", "fa-star-half", "fa-star-half-empty", "fa-star-half-full", "fa-star-half-o", "fa-star-o", "fa-steam", "fa-steam-square", "fa-step-backward", "fa-step-forward", "fa-stethoscope", "fa-stop", "fa-street-view", "fa-strikethrough", "fa-stumbleupon", "fa-stumbleupon-circle", "fa-subscript", "fa-subway", "fa-suitcase", "fa-sun-o", "fa-superscript", "fa-support", "fa-table", "fa-tablet", "fa-tachometer", "fa-tag", "fa-tags", "fa-tasks", "fa-taxi", "fa-tencent-weibo", "fa-terminal", "fa-text-height", "fa-text-width", "fa-th", "fa-th-large", "fa-th-list", "fa-thumb-tack", "fa-thumbs-down", "fa-thumbs-o-down", "fa-thumbs-o-up", "fa-thumbs-up", "fa-ticket", "fa-times", "fa-times-circle", "fa-times-circle-o", "fa-tint", "fa-toggle-down", "fa-toggle-left", "fa-toggle-off", "fa-toggle-on", "fa-toggle-right", "fa-toggle-up", "fa-train", "fa-transgender", "fa-transgender-alt", "fa-trash", "fa-trash-o", "fa-tree", "fa-trello", "fa-trophy", "fa-truck", "fa-try", "fa-tty", "fa-tumblr", "fa-tumblr-square", "fa-turkish-lira", "fa-twitch", "fa-twitter", "fa-twitter-square", "fa-umbrella", "fa-underline", "fa-undo", "fa-university", "fa-unlink", "fa-unlock", "fa-unlock-alt", "fa-unsorted", "fa-upload", "fa-usd", "fa-user", "fa-user-md", "fa-user-plus", "fa-user-secret", "fa-user-times", "fa-users", "fa-venus", "fa-venus-double", "fa-venus-mars", "fa-viacoin", "fa-video-camera", "fa-vimeo-square", "fa-vine", "fa-vk", "fa-volume-down", "fa-volume-off", "fa-volume-up", "fa-warning", "fa-wechat", "fa-weibo", "fa-weixin", "fa-whatsapp", "fa-wheelchair", "fa-wifi", "fa-windows", "fa-won", "fa-wordpress", "fa-wrench", "fa-xing", "fa-xing-square", "fa-yahoo", "fa-yelp", "fa-yen", "fa-youtube", "fa-youtube-play", "fa-youtube-square");
    sort( $icons );
    $iconArray = array();
    foreach ( $icons as $icon ) {
        $name = ucwords( str_replace( '-', ' ', str_replace( array(
            'fa-',
            '-play',
            '-square',
            '-alt',
            '-circle'
        ), '', $icon ) ) );
        $iconArray[ 'fa ' . $icon ] = $name;
    };


    /*
     *
     * ---> START SECTIONS
     *
     */

    /*

        As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for


     */

    // -> Content Ayarları
    Redux::setSection( $opt_name, array(
        'title'         => __( 'Anasayfa Ayarları', KRYEX_TEXT ),
        'id'            => 'content-options',
        'icon'          => 'el el-cogs',
        'fields'        => array(
            array(
                'id'       => 'h1_homepage_title',
                'type'     => 'text',
                'title'    => __( 'Anasayfa için H1 başlığı', KRYEX_TEXT ),
                'subtitle' => __( 'Bu başlık Sadece Anasayfada logo altına eklenir fakat görünmez. Seo için faydalıdır.', KRYEX_TEXT ),
                'desc'     => __( 'Boş bırakılırsa Site başlığı ve sloganı default olarak ayarlanır.', KRYEX_TEXT ),
            ),          
        )
    ) );

    // -> İçerik Ayarları
    Redux::setSection( $opt_name, array(
        'title'         => __( 'İçerik Ayarları', KRYEX_TEXT ),
        'id'            => 'single-options',
        'icon'          => 'el el-cogs',
        'fields'        => array(

            array(
                'id'       => 'single-like-hide',
                'type'     => 'button_set',
                'title'    => __( 'Beğen Butonu', KRYEX_TEXT ),
                'options'  => array(
                    '1'    => 'Göster',
                    '2'    => 'Gizle'
                ),
                'default'  => '1'
            ),
            array(
                'id'       => 'single-postviews-hide',
                'type'     => 'button_set',
                'title'    => __( 'Yazı Görüntülenmesi', KRYEX_TEXT ),
                'subtitle' => __( 'Gizli olsa bile arka planda görüntülenme sayısı çalışır.', KRYEX_TEXT ),
                'options'  => array(
                    '1'    => 'Göster',
                    '2'    => 'Gizle'
                ),
                'default'  => '1'
            ),
            array(
                'id'       => 'single-tag-hide',
                'type'     => 'button_set',
                'title'    => __( 'Etiketler', KRYEX_TEXT ),
                'options'  => array(
                    '1'    => 'Göster',
                    '2'    => 'Gizle'
                ),
                'default'  => '1'
            ),
            array(
                'id'       => 'single-meta-hide',
                'type'     => 'button_set',
                'title'    => __( 'Tarih', KRYEX_TEXT ),
                'subtitle' => __( 'Bu tarihi ve kategoriyi görterir veya gizler.', KRYEX_TEXT ),
                'options'  => array(
                    '1'    => 'Göster',
                    '2'    => 'Gizle'
                ),
                'default'  => '1'
            ),
            array(
                'id'       => 'single-author-hide',
                'type'     => 'button_set',
                'title'    => __( 'Yazar', KRYEX_TEXT ),
                'options'  => array(
                    '1'    => 'Göster',
                    '2'    => 'Gizle'
                ),
                'default'  => '1'
            ),
            array(
                'id'       => 'single-share-hide',
                'type'     => 'button_set',
                'title'    => __( 'Paylaşım Butonları', KRYEX_TEXT ),
                'options'  => array(
                    '1'    => 'Göster',
                    '2'    => 'Gizle'
                ),
                'default'  => '1'
            ),
            array(
                'id'       => 'single-comments-hide',
                'type'     => 'button_set',
                'title'    => __( 'Yorum Alanı', KRYEX_TEXT ),
                'options'  => array(
                    '1'    => 'Göster',
                    '2'    => 'Gizle'
                ),
                'default'  => '1'
            ),
            array(
                'id'       => 'single-link-nav-hide',
                'type'     => 'button_set',
                'title'    => __( 'Navigasyon Linkleri', KRYEX_TEXT ),
                'options'  => array(
                    '1'    => 'Göster',
                    '2'    => 'Gizle'
                ),
                'default'  => '1'
            ),
            array (
                'id'    => 'opt_single1',
                'icon'  => true,
                'type'  => 'info',
                'raw'   => '<h3 style="margin:0;color:#fff;">' . __( 'Benzer Yazılar', KRYEX_TEXT ) . '</h3>',
            ),
            array(
                'id'       => 'single-releated-hide',
                'type'     => 'button_set',
                'title'    => __( 'Benzer Yazılar', KRYEX_TEXT ),
                'options'  => array(
                    '1'    => 'Göster',
                    '2'    => 'Gizle'
                ),
                'default'  => '1'
            ),
            array(
                'id'       => 'releated_number',
                'type'     => 'text',
                'validate' => 'numeric',
                'title'    => __( 'Benzer yazılarda görüntülenecek yazı sayısı ', KRYEX_TEXT ),
                'default'  => '4'
            ),
        )
    ) );
    
    // -> Header Ayarları
    Redux::setSection( $opt_name, array(
        'title'         => __( 'Header Ayarları', KRYEX_TEXT ),
        'id'            => 'header-options',
        'icon'          => 'el el-wrench',
        'fields'        => array(
            array(
                'id'       => 'logo-upload',
                'type'     => 'media', 
                'url'      => true,
                'title'    => __( 'Logo Yükle', KRYEX_TEXT ),
                'default'  => array(
                    'url'  => get_template_directory_uri().'/img/logo.png'
                )
            ),
        )
    ) );

    // -> Sosyal Medya
    Redux::setSection( $opt_name, array(
        'title'         => __( 'Sosyal Medya', KRYEX_TEXT ),
        'id'            => 'socials-options',
        'icon'          => 'el el-twitter',
        'fields'        => array(
            array(
                'id'       => 'instagram_link',
                'type'     => 'text',
                'validate' => 'url',
                'title'    => __( 'İnstagram link', KRYEX_TEXT ),
                'default'  => 'https://instagram.com/kryextheme'
            ),
            array(
                'id'       => 'twitter_link',
                'type'     => 'text',
                'validate' => 'url',
                'title'    => __( 'Twitter link', KRYEX_TEXT ),
                'default'  => 'https://twitter.com/kryextheme'
            ),
            array(
                'id'       => 'facebook_link',
                'type'     => 'text',
                'validate' => 'url',
                'title'    => __( 'Facebook link', KRYEX_TEXT ),
                'default'  => 'https://facebook.com/kryextheme'
            ),
            array(
                'id'       => 'pinterest_link',
                'type'     => 'text',
                'validate' => 'url',
                'title'    => __( 'Pinterest link', KRYEX_TEXT ),
                'default'  => 'https://pinterest.com/kryextheme/'
            ),
            array(
                'id'       => 'whatsapp_link',
                'type'     => 'text',
                'title'    => __( 'Whatsapp link', KRYEX_TEXT ),
                'default'  => '#'
            ),
            array(
                'id'       => 'youtube_link',
                'type'     => 'text',
                'validate' => 'url',
                'title'    => __( 'Youtube link', KRYEX_TEXT ),
                'default'  => 'https://www.youtube.com/channel/UCeUtf3fiXa7OFdSMP7_Qy4g'
            ),
            
        )
    ) );

    // -> Stil Ayarları
    Redux::setSection( $opt_name, array(
        'title'         => __( 'Stil Ayarları', KRYEX_TEXT ),
        'id'            => 'style-options',
        'icon'          => 'el el-tint',
        'desc'          => 'Websitenizin stil ayarlarını buradan yapın.',
        'fields'        => array(
            array(
                'id'          => 'genel-renk',
                'type'        => 'color',
                'output'    => array( 'blockquote,.category_view_all:hover,.mega-menu .sub-cats li.active-item a,.socialButton:hover,.menu ul.sub-menu li.current-menu-item.nx_Current > a,.menu ul.sub-menu li.menu-item-has-children:hover > a, .header.centered .menu > li.menu-item-has-children:hover > a, #mobile-menu li.menu-item-has-children.active > a, #mobile-menu li.menu-item-has-children.active > .menu-toggle, .header.centered .menu > li > a:hover,.entry-content.single-post-content a,.mega-menu-content .mega-menu-item:hover .entry-header a,.header, a:hover, .nx-footer, .navbar-primary .navbar-nav > li.menu-item.menu-item-expanded > a, .navbar-primary .navbar-nav > li.menu-item > a:hover, .clp > .navbar-nav > li a:hover, .navbar-primary .navbar-nav > li.menu-item.current-menu-item a, .clp > .navbar-nav > li.current-menu-item a,#loginPopup .modal-header .close:hover' ),
                'default'     => '#6e6abf',
                'title'       => __( 'Genel link rengi', KRYEX_TEXT )
            ),

            array(
                'id'          => 'top_post_cat_color',
                'type'        => 'background',
                'default'     => array('background-color' => '#6e6abf'),
                'output'      => array( '.post_list_top .post_category a, .home-sidebar .cat-item span' ),
                'title'       => __( 'Üst kısım Kategori rengi', KRYEX_TEXT ),
                'background-color'      => true,
                'background-repeat'     => false,
                'background-attachment' => false,
                'background-position'   => false,
                'background-image'      => false,
                'background-size'       => false,
                'preview'               => false
            ),

            array(
                'id'          => 'top_post_cat_color2',
                'type'        => 'background',
                'default'     => array('background-color' => '#222222'),
                'output'      => array( '.post_list_top .post_category a:hover' ),
                'title'       => __( 'Üst kısım Kategori hover rengi', KRYEX_TEXT ),
                'background-color'      => true,
                'background-repeat'     => false,
                'background-attachment' => false,
                'background-position'   => false,
                'background-image'      => false,
                'background-size'       => false,
                'preview'               => false
            ),

            array (
                'id'    => 'opt_divi1286',
                'icon'  => true,
                'type'  => 'info',
                'raw'   => '<h3 style="margin:0;color:#fff;">' . __( 'Bileşen renkleri', KRYEX_TEXT ) . '</h3>',
            ),

            array(
                'id'          => 'widgets_title_bg_color',
                'type'        => 'background',
                'default'     => array('background-color' => '#222222'),
                'output'      => array( '.home-sidebar .section_title' ),
                'title'       => __( 'Bileşenler başlığı arkaplan rengi', KRYEX_TEXT ),
                'background-color'      => true,
                'background-repeat'     => false,
                'background-attachment' => false,
                'background-position'   => false,
                'background-image'      => false,
                'background-size'       => false,
                'preview'               => false
            ),

            array(
                'id'          => 'widgets_cats_bg_color',
                'type'        => 'background',
                'default'     => array('background-color' => '#222222'),
                'output'      => array( '.last-post-items .post_category a' ),
                'title'       => __( 'Yazı Kategorisi arkaplan rengi', KRYEX_TEXT ),
                'background-color'      => true,
                'background-repeat'     => false,
                'background-attachment' => false,
                'background-position'   => false,
                'background-image'      => false,
                'background-size'       => false,
                'preview'               => false
            ),

            array(
                'id'          => 'widgets_cats_color_hover',
                'type'        => 'background',
                'default'     => array('background-color' => '#6e6abf'),
                'output'      => array( '.last-post-items .post_category a:hover' ),
                'title'       => __( 'Yazı Kategorisi hover rengi', KRYEX_TEXT ),
                'background-color'      => true,
                'background-repeat'     => false,
                'background-attachment' => false,
                'background-position'   => false,
                'background-image'      => false,
                'background-size'       => false,
                'preview'               => false
            ),

            array(
                'id'          => 'tag-bg-color',
                'type'        => 'background',
                'default'     => array('background-color' => '#222'),
                'output'      => array( '.tagcloud a' ),
                'title'       => __( 'Etiketlerin arkaplan rengi', KRYEX_TEXT ),
                'background-color'      => true,
                'background-repeat'     => false,
                'background-attachment' => false,
                'background-position'   => false,
                'background-image'      => false,
                'background-size'       => false,
                'preview'               => false
            ),
            array(
                'id'          => 'tag-bg-hovercolor',
                'type'        => 'background',
                'default'     => array('background-color' => '#6e6abf'),
                'output'      => array( '.tagcloud a:hover' ),
                'title'       => __( 'Etiketlerin arkaplan hover rengi', KRYEX_TEXT ),
                'background-color'      => true,
                'background-repeat'     => false,
                'background-attachment' => false,
                'background-position'   => false,
                'background-image'      => false,
                'background-size'       => false,
                'preview'               => false
            ),

            array (
                'id'    => 'opt_divi128',
                'icon'  => true,
                'type'  => 'info',
                'raw'   => '<h3 style="margin:0;color:#fff;">' . __( 'Menü renkleri', KRYEX_TEXT ) . '</h3>',
            ),
            array(
                'id'          => 'current_menu_bgcolor',
                'type'        => 'background',
                'default'     => array('background-color' => '#6e6abf'),
                'output'    => array( '.main-menu ul.menu > li.menu-item.nx_Current > a' ),
                'title'       => __( 'Menü aktif arkaplan rengi', KRYEX_TEXT ),
                'background-color'      => true,
                'background-repeat'     => false,
                'background-attachment' => false,
                'background-position'   => false,
                'background-image'      => false,
                'background-size'       => false,
                'preview'               => false
            ),
            array(
                'id'          => 'menu_bgcolor',
                'type'        => 'background',
                'default'     => array('background-color' => '#222222'),
                'output'    => array( '.fix' ),
                'title'       => __( 'Menü arkaplan rengi', KRYEX_TEXT ),
                'background-color'      => true,
                'background-repeat'     => false,
                'background-attachment' => false,
                'background-position'   => false,
                'background-image'      => false,
                'background-size'       => false,
                'preview'               => false
            ),

            array (
                'id'    => 'opt_divi13',
                'icon'  => true,
                'type'  => 'info',
                'raw'   => '<h3 style="margin:0;color:#fff;">' . __( 'Sayfalama renkleri', KRYEX_TEXT ) . '</h3>',
            ),

            array(
                'id'          => 'pagination-color',
                'type'        => 'background',
                'default'     => array('background-color' => '#111',),
                'output'    => array( 'li .page-numbers' ),
                'title'       => __( 'Sayfalama rengi', KRYEX_TEXT ),
                'background-color'      => true,
                'background-repeat'     => false,
                'background-attachment' => false,
                'background-position'   => false,
                'background-image'      => false,
                'background-size'       => false,
                'preview'               => false
            ),
            array(
                'id'          => 'pagination-aktif-color',
                'type'        => 'background',
                'default'     => array('background-color' => '#6e6abf',),
                'output'    => array( '.page-numbers.current' ),
                'title'       => __( 'Sayfalama aktif rengi', KRYEX_TEXT ),
                'background-color'      => true,
                'background-repeat'     => false,
                'background-attachment' => false,
                'background-position'   => false,
                'background-image'      => false,
                'background-size'       => false,
                'preview'               => false
            ),

            array (
                'id'    => 'opt_divi5',
                'icon'  => true,
                'type'  => 'info',
                'raw'   => '<h3 style="margin:0;color:#fff;">' . __( 'İçerik renk ayarları', KRYEX_TEXT ) . '</h3>',
            ),
            array(
                'id'          => 'singlepost-cat-bgcolor',
                'type'        => 'background',
                'default'     => array('background-color' => '#6e6abf'),
                'output'      => array( '.posted-in a, .single-postX .tags-list a:hover' ),
                'title'       => __( 'İçerik kategori rengi', KRYEX_TEXT ),
                'background-color'      => true,
                'background-repeat'     => false,
                'background-attachment' => false,
                'background-position'   => false,
                'background-image'      => false,
                'background-size'       => false,
                'preview'               => false
            ),

            array(
                'id'          => 'title_related_bg',
                'type'        => 'background',
                'default'     => array('background-color' => '#222222'),
                'output'      => array( '.releated-title' ),
                'title'       => __( 'Benzer yazılar arkaplan rengi', KRYEX_TEXT ),
                'background-color'      => true,
                'background-repeat'     => false,
                'background-attachment' => false,
                'background-position'   => false,
                'background-image'      => false,
                'background-size'       => false,
                'preview'               => false
            ),

            array(
                'id'          => 'singlepost-social-bgcolor',
                'type'        => 'background',
                'default'     => array('background-color' => '#6e6abf'),
                'output'      => array( '#comment-submit' ),
                'title'       => __( 'İçerik yorum Gönder butonun rengi', KRYEX_TEXT ),
                'background-color'      => true,
                'background-repeat'     => false,
                'background-attachment' => false,
                'background-position'   => false,
                'background-image'      => false,
                'background-size'       => false,
                'preview'               => false
            ),

            array (
                'id'    => 'opt_divi6',
                'icon'  => true,
                'type'  => 'info',
                'raw'   => '<h3 style="margin:0;color:#fff;">' . __( 'Arşiv renkleri', KRYEX_TEXT ) . '</h3>',
            ),

            array(
                'id'          => 'archivePost_bg_color',
                'type'        => 'background',
                'default'     => array('background-color' => '#6e6abf'),
                'output'    => array('.archivePost .section_title, .archivePost .post_category a'),
                'title'       => __( 'Arşiv başlık ve kategori linki arkaplan rengi', KRYEX_TEXT ),
                'background-color'      => true,
                'background-repeat'     => false,
                'background-attachment' => false,
                'background-position'   => false,
                'background-image'      => false,
                'background-size'       => false,
                'preview'               => false
            ),

            array (
                'id'    => 'opt_divi31',
                'icon'  => true,
                'type'  => 'info',
                'raw'   => '<h3 style="margin:0;color:#fff;">' . __( 'Üye profil renkleri', KRYEX_TEXT ) . '</h3>',
            ),

            array(
                'id'          => 'author-border',
                'type'        => 'border',
                'title'       => __('Üye profil border rengi', KRYEX_TEXT),
                'output'    => array('.author-profile .avatar, .Aut .author-photo .avatar'),
                'default'     => array(
                    'border-color'  => '#eeeeee',
                    'border-style'  => 'solid',
                    'border-top'    => '10px', 
                    'border-right'  => '10px', 
                    'border-bottom' => '10px', 
                    'border-left'   => '10px'
                )
            ),
            array(
                'id'          => 'author-border-hover',
                'type'        => 'border',
                'title'       => __('Üye profil border hover rengi', KRYEX_TEXT),
                'output'    => array('.col-cont:hover .author-profile .avatar'),
                'default'     => array(
                    'border-color'  => '#6e6abf',
                    'border-style'  => 'solid',
                    'border-top'    => '10px', 
                    'border-right'  => '10px', 
                    'border-bottom' => '10px', 
                    'border-left'   => '10px'
                )
            ),
            array(
                'id'          => 'Aut-social-color',
                'type'        => 'background',
                'default'     => array('background-color' => '#6e6abf' ),
                'output'    => array( '.socialsList .social-icon' ),
                'title'       => __( 'Üye profili sosyal medya buton rengi', KRYEX_TEXT ),
                'background-color'      => true,
                'background-repeat'     => false,
                'background-attachment' => false,
                'background-position'   => false,
                'background-image'      => false,
                'background-size'       => false,
                'preview'               => false
            ),
            array(
                'id'          => 'Aut-post-color',
                'type'        => 'background',
                'default'     => array('background-color' => '#6e6abf' ),
                'output'      => array( '.author .archivePost .section_title' ),
                'title'       => __( 'Üye profili yazılar başlığının arkaplan rengi', KRYEX_TEXT ),
                'background-color'      => true,
                'background-repeat'     => false,
                'background-attachment' => false,
                'background-position'   => false,
                'background-image'      => false,
                'background-size'       => false,
                'preview'               => false
            ),

            array (
                'id'    => 'opt_divi9',
                'icon'  => true,
                'type'  => 'info',
                'raw'   => '<h3 style="margin:0;color:#fff;">' . __( 'Yukarı çık butonu', KRYEX_TEXT ) . '</h3>',
            ),

            array(
                'id'          => 'back-top-color',
                'type'        => 'background',
                'default'     => array('background-color' => '#6e6abf'),
                'output'    => array( '#r_top' ),
                'title'       => __( 'Yukarı çık button rengi', KRYEX_TEXT ),
                'background-color'      => true,
                'background-repeat'     => false,
                'background-attachment' => false,
                'background-position'   => false,
                'background-image'      => false,
                'background-size'       => false,
                'preview'               => false
            ),
            array (
                'id'    => 'opt_divi2',
                'icon'  => true,
                'type'  => 'info',
                'raw'   => '<h3 style="margin:0;color:#fff;">' . __( 'Footer renkleri', KRYEX_TEXT ) . '</h3>',
            ),

            array(
                'id'          => 'copyright-background-color',
                'type'        => 'background',
                'default'     => array('background-color' => '#222'),
                'output'    => array( '.footer-copyright' ),
                'title'       => __( 'Copyright Arkaplan rengi', KRYEX_TEXT ),
                'background-color'      => true,
                'background-repeat'     => false,
                'background-attachment' => false,
                'background-position'   => false,
                'background-image'      => false,
                'background-size'       => false,
                'preview'               => false
            ),
            
        )
    ) );

    // -> Tipografi
    Redux::setSection( $opt_name, array(
        'title'  => __( 'Tipografi', KRYEX_TEXT ),
        'id'     => 'typography',
        'desc'   => __( 'Web sitesi yazı tipi ayarlarınızı buradan yapabilirsiniz. ', KRYEX_TEXT ),
        'icon'   => 'el el-font',
        'fields' => array(
            array(
                'id'       => 'typography-body',
                'type'     => 'typography',
                'google'   => true,
                'font-style'    => false,
                'font-size'     => false,
                'font-weight'   => false,
                'text-align'    => false,
                'color'         => false,
                'all_styles'    => true,
                'font-backup'   => true,
                'line-height'   => false,
                'subsets'       => true,
                'output'      => array( 'body' ),
                'title'         => __( 'Body Fontunu değiştir', KRYEX_TEXT ),
                'default'       => array(
                    'font-family' => 'Poppins', 
                    'font-backup' => 'Arial, Helvetica, sans-serif',
                ),
            ),
            array(
                'id'       => 'typography-menu',
                'type'     => 'typography',
                'google'   => true,
                'font-style'   => false,
                'font-size'    => true,
                'font-weight'  => true,
                'text-align'   => false,
                'color'        => false,
                'all_styles'   => true,
                'font-backup'  => true,
                'line-height'  => false,
                'subsets'      => true,
                'output'       => array( '#mobile-menu li.menu-item a,.header.centered .menu > li > a,.search-form input,.mega-menu.mega-menu-tabs .tabs-content .sub-cats li a' ),
                'title'    => __( 'Menü Fontunu değiştir', KRYEX_TEXT ),
                'default'     => array(
                    'font-family' => 'Poppins', 
                    'font-backup' => 'Arial, Helvetica, sans-serif',
                    'font-size'   => '12px',
                    'font-weight' => '700',
                ),
            ),

     ) ) );

    // -> Blog Ayarları
    Redux::setSection( $opt_name, array(
        'title'         => __( 'Blog Ayarları', KRYEX_TEXT ),
        'id'            => 'blog-options',
        'icon'          => 'el el-pencil',
        'fields'        => array(
            array(
                'id'        => 'pagex_blog',
                'type'      => 'image_select',
                'title'     => __( 'Anasayfa Üst Kısım düzeni', KRYEX_TEXT ),
                'options'   => array(
                    'default'   => array( 'alt' => 'Default','title' => 'Default', 'img' => KRYEX_THEME_URI . '/img/default.png' ),
                    /*'carousel'  => array( 'alt' => 'Carousel','title' => 'Carousel', 'img' => KRYEX_THEME_URI . '/img/carousel.png' ),*/
                ),
                'default'   => 'carousel'
            ),

            array(
               'id' => 'category_section_slider',
               'type' => 'select',
               'data' => 'categories',
               'multi' => true,
               'title' => __('Anasayfa Üst Kısım için kategori seçin', KRYEX_TEXT)
            ),

            array (
                'id'    => 'opt_blog2',
                'icon'  => true,
                'type'  => 'info',
                'raw'   => '<h3 style="margin:0;color:#fff;">' . __( 'Genel Tarih formatı', KRYEX_TEXT ) . '</h3>',
            ),

            array(
                'id'       => 'date_format',
                'type'     => 'button_set',
                'title'    => __( 'Tarih Formatı', KRYEX_TEXT ),
                'subtitle' => __( 'Genel Tarih Formatını değiştirin', KRYEX_TEXT ),
                'options'  => array(
                    '1'    => 'Normal (02.Mart.2020)',
                    '2'    => 'Gün (1 gün önce)'
                ),
                'default'  => '2'
            ),
            array (
                'id'    => 'opt_cat_list',
                'icon'  => true,
                'type'  => 'info',
                'raw'   => '<h3 style="margin:0;color:#fff;">' . __( 'Anasayfa resimli kategoriler', KRYEX_TEXT ) . '</h3>',
            ),
            array(
                'id'        => 'catlist_orderby',
                'type'      => 'select',
                'title'     => __( 'Kategorileri sırala', KRYEX_TEXT ),
                'options'   => array( 'name' => 'İsme göre', 'count' => 'Yazı sayısına göre' ),
                'default'   => 'count'
            ),
            array(
                'id'        => 'catlist_order',
                'type'      => 'select',
                'title'     => __( 'Kategori order sıralaması', KRYEX_TEXT ),
                'options'   => array( 'ASC' => 'ASC', 'DESC' => 'DESC' ),
                'default'   => 'DESC'
            ),
        )
    ) );

    // -> Üyeler Sayfası
    Redux::setSection( $opt_name, array(
        'title'         => __( 'Üyeler Sayfası', KRYEX_TEXT ),
        'id'            => 'author-options',
        'icon'          => 'el el-user',
        'fields'        => array(
            array(
                'id'       => 'Author_count',
                'type'     => 'text',
                'validate' => 'numeric',
                'title'    => __( 'Üyeler sayfasında gösterilecek üye sayısı', KRYEX_TEXT ),
                'default'  => '12'
            ),
            array(
                'id'        => 'Aut_orderby',
                'type'      => 'select',
                'title'     => __( 'Üye sıralaması', KRYEX_TEXT ),
                'options'   => array( 'registered' => 'Kayıt sırasına göre', 'display_name' => 'İsim sırasına göre', 'post_count' => 'Yazı sayısına göre' ),
                'default'   => 'registered'
            ),
            array(
                'id'        => 'Aut_date',
                'type'      => 'select',
                'title'     => __( 'Tarih Sıralaması', KRYEX_TEXT ),
                'options'   => array( 'asc' => 'Yeniden eskiye', 'desc' => 'Eskiden yeniye' ),
                'default'   => 'asc'
            ),
            array(
                'id'       => 'Aut_br_text',
                'type'     => 'text',
                'title'    => __( 'Üyeler sayfası breadcrumb yazısı', KRYEX_TEXT ),
                'subtitle' => __( 'Üyeler sayfası için oluşturduğunuz sayfanın başlığı', KRYEX_TEXT ),
                'default'  => 'Üyeler'
            ),
            array(
                'id'       => 'Aut_br_link',
                'type'     => 'text',
                'validate' => 'html',
                'title'    => __( 'Üyeler sayfası breadcrumb linki', KRYEX_TEXT ),
                'subtitle' => __( 'Üyeler sayfası için oluşturduğunuz sayfanın linki', KRYEX_TEXT ),
                'desc'     => __( 'https://kryextheme.com/<strong>uyeler</strong>/ <br> (Sayfaya bağlantısı sadece örnekteki gibi "uyeler" olarak alınmalıdır. )', KRYEX_TEXT ),
                'default'  => 'uyeler'
            ),


        )
    ) );

    // -> Footer Ayarları
    Redux::setSection( $opt_name, array(
        'title'         => __( 'Footer Ayarları', KRYEX_TEXT ),
        'id'            => 'footer-options',
        'icon'          => 'el el-wrench',
        'fields'        => array(
            array(
                'id'       => 'copyright-text',
                'type'     => 'editor',
                'title'    => __( 'Copyright text', KRYEX_TEXT ),
                'default'  => 'Copyright © Kryex Nano &nbsp; - &nbsp;<i style="color:#6e6abf;" class="icofont-heart-alt"></i>&nbsp; <a href="https://kryexthemes.com" target="_blank">Kryex Themes</a>'
            ),
        )
    ) );

    // -> Reklam Alanları
    Redux::setSection( $opt_name, array(
        'title'         => __( 'Reklam Alanları', KRYEX_TEXT ),
        'id'            => 'ads-options',
        'icon'          => 'el el-bullhorn',
        'fields'        => array(
            array (
                'id'    => 'opt_ads1',
                'icon'  => true,
                'type'  => 'info',
                'raw'   => '<h3 style="margin:0;color:#fff;">' . __( 'İçerik reklam alanları', KRYEX_TEXT ) . '</h3>',
            ),
            array(
                'id'       => 'ads_single_post_top_hide',
                'type'     => 'button_set',
                'title'    => __( 'içerik yazı üst kısım', KRYEX_TEXT ),
                'options'  => array(
                    '1'    => 'Göster',
                    '2'    => 'Gizle'
                ),
                'default'  => '1'
            ),
            array(
                'id'       => 'ads_single_post_top',
                'type'     => 'textarea',
                'title'    => __( 'içerik yazı üst kısım KODU', KRYEX_TEXT ),
                'default'  => '<img src="'.KRYEX_THEME_URI.'/img/singlebanner.png" alt="ads" width="770" height="105">'
            ),
            array(
                'id'       => 'ads_single_post_bottom_hide',
                'type'     => 'button_set',
                'title'    => __( 'içerik yazı alt kısım', KRYEX_TEXT ),
                'options'  => array(
                    '1'    => 'Göster',
                    '2'    => 'Gizle'
                ),
                'default'  => '1'
            ),
            array(
                'id'       => 'ads_single_post_bottom',
                'type'     => 'textarea',
                'title'    => __( 'içerik yazı alt kısım KODU', KRYEX_TEXT ),
                'default'  => '<img src="'.KRYEX_THEME_URI.'/img/singlebanner.png" alt="ads" width="770" height="105">'
            ),

        )
    ) );

    // -> Giriş Sayfası Ayarları
    Redux::setSection( $opt_name, array(
        'title'         => __( 'Giriş Sayfası Ayarları', KRYEX_TEXT ),
        'id'            => 'login-options',
        'icon'          => 'el el-wrench',
        'fields'        => array(
            array(
                'id'       => 'logo_upload',
                'type'     => 'media',
                'title'    => __( 'Logo Yükle', KRYEX_TEXT ),
                'default'  => array(
                    'url'  => KRYEX_THEME_URI.'/img/logo.png'
                )
            ),
            array(
                'id'       => 'logo_bg',
                'type'     => 'media',
                'title'    => __( 'Arkaplan resmi Yükle', KRYEX_TEXT ),
                'default'  => array(
                    'url'  => KRYEX_THEME_URI.'/img/thumb_bg.jpg'
                )
            ),
        )
    ) );

        // -> Tema Dili
    Redux::setSection( $opt_name, array(
        'title'         => __( 'Tema Dili', KRYEX_TEXT ),
        'id'            => 'language-options',
        'icon'          => 'el el-text-width',
        'fields'        => array(
            array(
                'id'       => 'lang_search',
                'type'     => 'text',
                'title'    => __( 'Arama', KRYEX_TEXT ),
                'default'  => 'Arama...'
            ),
            array(
                'id'       => 'lang_search_x',
                'type'     => 'text',
                'title'    => __( 'ARA', KRYEX_TEXT ),
                'default'  => 'ARA'
            ),
            array(
                'id'       => 'goruntulenme',
                'type'     => 'text',
                'title'    => __( 'Görüntülenme', KRYEX_TEXT ),
                'default'  => 'Görüntülenme'
            ),
            array(
                'id'       => 'like_text',
                'type'     => 'text',
                'title'    => __( 'Beğen', KRYEX_TEXT ),
                'default'  => 'Beğen'
            ),
            array(
                'id'       => 'unlike_text',
                'type'     => 'text',
                'title'    => __( 'Beğenmekten Vazgeç', KRYEX_TEXT ),
                'default'  => 'Vazgeç'
            ),
            array(
                'id'       => 'lang_share_twitter',
                'type'     => 'text',
                'title'    => __( 'Twitter da paylaş', KRYEX_TEXT ),
                'default'  => 'Twitter da paylaş'
            ),
            array(
                'id'       => 'lang_share_facebook',
                'type'     => 'text',
                'title'    => __( 'Facebook ta paylaş', KRYEX_TEXT ),
                'default'  => 'Facebook ta paylaş'
            ),
            array(
                'id'       => 'lang_share_whatsapp',
                'type'     => 'text',
                'title'    => __( 'Whatsapp da paylaş', KRYEX_TEXT ),
                'default'  => 'Whatsapp da paylaş'
            ),
            array(
                'id'       => 'lang_share_pinterest',
                'type'     => 'text',
                'title'    => __( 'Pinterest da paylaş', KRYEX_TEXT ),
                'default'  => 'Pinterest da paylaş'
            ),
            array(
                'id'       => 'prev_post',
                'type'     => 'text',
                'title'    => __( 'Önceki yazı', KRYEX_TEXT ),
                'default'  => 'Önceki yazı'
            ),
            array(
                'id'       => 'next_post',
                'type'     => 'text',
                'title'    => __( 'Sonraki yazı', KRYEX_TEXT ),
                'default'  => 'Sonraki yazı'
            ),
            array(
                'id'       => 'lang_comments',
                'type'     => 'text',
                'title'    => __( ' Yorum', KRYEX_TEXT ),
                'default'  => ' Yorum'
            ),
            array(
                'id'       => 'tit_yorumlar',
                'type'     => 'text',
                'title'    => __( 'Yorumlar', KRYEX_TEXT ),
                'default'  => 'Yorumlar'
            ),
            array(
                'id'       => 'tit_yorumlar_kapali',
                'type'     => 'text',
                'title'    => __( 'Yorum kapalı', KRYEX_TEXT ),
                'default'  => 'Yorum kapalı'
            ),
            array(
                'id'       => 'lang_message',
                'type'     => 'text',
                'title'    => __( 'Mesajınız', KRYEX_TEXT ),
                'default'  => 'Mesajınız'
            ),
            array(
                'id'       => 'lang_name',
                'type'     => 'text',
                'title'    => __( 'isim *', KRYEX_TEXT ),
                'default'  => 'isim *'
            ),
            array(
                'id'       => 'lang_email',
                'type'     => 'text',
                'title'    => __( 'Email *', KRYEX_TEXT ),
                'default'  => 'Email *'
            ),
            array(
                'id'       => 'arama_sonuc',
                'type'     => 'text',
                'title'    => __( 'Arama Sonuçları', KRYEX_TEXT ),
                'default'  => 'Arama Sonuçları'
            ),
            array(
                'id'       => 'sonuc_bulunamadi',
                'type'     => 'text',
                'title'    => __( 'Sonuç Bulunamadı', KRYEX_TEXT ),
                'default'  => '<strong>Üzgünüz,</strong> hiç sonuç bulunamadı.'
            ),
            array(
                'id'       => 'sayfa_bulunamadi',
                'type'     => 'text',
                'title'    => __( 'Sayfa bulunamadı !', KRYEX_TEXT ),
                'default'  => 'Sayfa bulunamadı !'
            ),
            array(
                'id'       => 'p_uzgunuz',
                'type'     => 'text',
                'title'    => __( 'Üzgünüz...', KRYEX_TEXT ),
                'default'  => 'Üzgünüz, ancak görüntülemeye çalıştığınız sayfa mevcut değil.'
            ),
            array(
                'id'       => 'to_top',
                'type'     => 'text',
                'title'    => __( 'Yukarı Git', KRYEX_TEXT ),
                'default'  => 'Yukarı Git'
            ),

            array(
                'id'   => 'opt-dividelang1',
                'type' => 'divide'
            ),

            array(
                'id'       => 'log_in',
                'type'     => 'text',
                'title'    => __( 'Giriş Yap', KRYEX_TEXT ),
                'default'  => 'Giriş Yap'
            ),
            array(
                'id'       => 'log_out',
                'type'     => 'text',
                'title'    => __( 'Çıkış Yap', KRYEX_TEXT ),
                'default'  => 'Çıkış Yap'
            ),
            array(
                'id'       => 'log_admin',
                'type'     => 'text',
                'title'    => __( 'Wp Admin', KRYEX_TEXT ),
                'default'  => 'Wp Admin'
            ),

            array(
                'id'   => 'opt-dividelang321',
                'type' => 'divide'
            ),

            array(
                'id'       => 'bread_home',
                'type'     => 'text',
                'title'    => __( 'Anasayfa', KRYEX_TEXT ),
                'subtitle' => __( 'Breadcrumb Anasayfa metni', KRYEX_TEXT ),
                'default'  => 'Anasayfa'
            ),

            array(
                'id'       => 'related_post_text',
                'type'     => 'text',
                'title'    => __( 'Benzer Yazılar', KRYEX_TEXT ),
                'subtitle' => __( 'Benzer Yazılar metni', KRYEX_TEXT ),
                'default'  => 'Benzer Yazılar'
            ),

            array(
                'id'   => 'opt-dividelang334',
                'type' => 'divide'
            ),

            array(
                'id'       => 'aut_list_postText',
                'type'     => 'text',
                'title'    => __( 'Yazı', KRYEX_TEXT ),
                'subtitle' => __( 'Üye listesi yazı sayısı metni', KRYEX_TEXT ),
                'default'  => 'Yazı'
            ),
            array(
                'id'       => 'Aut_Post_nameX',
                'type'     => 'text',
                'title'    => __( 'Yazılar', KRYEX_TEXT ),
                'subtitle' => __( 'Üye profili yazıların üst başlığı', KRYEX_TEXT ),
                'default'  => 'Yazılar'
            ),
            array(
                'id'       => 'no_post_member',
                'type'     => 'text',
                'title'    => __( 'Bu üyenin yazısı yok.', KRYEX_TEXT ),
                'default'  => 'Bu üyenin yazısı yok.'
            ),
        )
    ) );



    /*
     * <--- END SECTIONS
     */


    /*
     *
     * YOU MUST PREFIX THE FUNCTIONS BELOW AND ACTION FUNCTION CALLS OR ANY OTHER CONFIG MAY OVERRIDE YOUR CODE.
     *
     */

    /*
    *
    * --> Action hook examples
    *
    */

    // If Redux is running as a plugin, this will remove the demo notice and links
    //add_action( 'redux/loaded', 'remove_demo' );

    // Function to test the compiler hook and demo CSS output.
    // Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
    /*add_filter('redux/options/' . $opt_name . '/compiler', 'compiler_action', 10, 3);

    function compiler_action($options, $css, $changed_values) {
        global $wp_filesystem;
     
        $filename = dirname(__FILE__) . '/style.css';
     
        if( empty( $wp_filesystem ) ) {
            require_once( ABSPATH .'/wp-admin/includes/file.php' );
            WP_Filesystem();
        }
     
        if( $wp_filesystem ) {
            $wp_filesystem->put_contents(
                $filename,
                $css,
                FS_CHMOD_FILE // predefined mode settings for WP files
            );
        }
    }*/

    // Change the arguments after they've been declared, but before the panel is created
    //add_filter('redux/options/' . $opt_name . '/args', 'change_arguments' );

    // Change the default value of a field after it's been set, but before it's been useds
    //add_filter('redux/options/' . $opt_name . '/defaults', 'change_defaults' );

    // Dynamically add a section. Can be also used to modify sections/fields
    //add_filter('redux/options/' . $opt_name . '/sections', 'dynamic_section');

    /**
     * This is a test function that will let you see when the compiler hook occurs.
     * It only runs if a field    set with compiler=>true is changed.
     * */
    /*if ( ! function_exists( 'compiler_action' ) ) {
        function compiler_action( $options, $css, $changed_values ) {
            echo '<h1>The compiler hook has run!</h1>';
            echo "<pre>";
            print_r( $changed_values ); // Values that have changed since the last save
            echo "</pre>";
            //print_r($options); //Option values
            //print_r($css); // Compiler selector CSS values  compiler => array( CSS SELECTORS )
        }
    }*/

    /**
     * Custom function for the callback validation referenced above
     * */
    if ( ! function_exists( 'redux_validate_callback_function' ) ) {
        function redux_validate_callback_function( $field, $value, $existing_value ) {
            $error   = false;
            $warning = false;

            //do your validation
            if ( $value == 1 ) {
                $error = true;
                $value = $existing_value;
            } elseif ( $value == 2 ) {
                $warning = true;
                $value   = $existing_value;
            }

            $return['value'] = $value;

            if ( $error == true ) {
                $field['msg']    = 'your custom error message';
                $return['error'] = $field;
            }

            if ( $warning == true ) {
                $field['msg']      = 'your custom warning message';
                $return['warning'] = $field;
            }

            return $return;
        }
    }

    /**
     * Custom function for the callback referenced above
     */
    if ( ! function_exists( 'redux_my_custom_field' ) ) {
        function redux_my_custom_field( $field, $value ) {
            print_r( $field );
            echo '<br/>';
            print_r( $value );
        }
    }

    /**
     * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
     * Simply include this function in the child themes functions.php file.
     * NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
     * so you must use get_template_directory_uri() if you want to use any of the built in icons
     * */
    if ( ! function_exists( 'dynamic_section' ) ) {
        function dynamic_section( $sections ) {
            //$sections = array();
            $sections[] = array(
                'title'  => __( 'Section via hook', KRYEX_TEXT ),
                'desc'   => __( '<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', KRYEX_TEXT ),
                'icon'   => 'el el-paper-clip',
                // Leave this as a blank section, no options just some intro text set above.
                'fields' => array()
            );

            return $sections;
        }
    }

    /**
     * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
     * */
    if ( ! function_exists( 'change_arguments' ) ) {
        function change_arguments( $args ) {
            //$args['dev_mode'] = true;

            return $args;
        }
    }


    /**
     * Filter hook for filtering the default value of any given field. Very useful in development mode.
     * */
    if ( ! function_exists( 'change_defaults' ) ) {
        function change_defaults( $defaults ) {
            $defaults['str_replace'] = 'Testing filter hook!';

            return $defaults;
        }
    }

    /**
     * Removes the demo link and the notice of integrated demo from the redux-framework plugin
     */
    if ( ! function_exists( 'remove_demo' ) ) {
        function remove_demo() {
            // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
            if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
                remove_filter( 'plugin_row_meta', array(
                    ReduxFrameworkPlugin::instance(),
                    'plugin_metalinks'
                ), null, 2 );

                // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
                remove_action( 'admin_notices', array( ReduxFrameworkPlugin::instance(), 'admin_notices' ) );
            }
        }
    }
